-module(recon_test).

-compile([export_all, nowarn_export_all]).

-define(MEM_INFO_INIT(), memInfoInit(?MODULE, ?LINE)).
-define(MEM_INFO_PRINT(), memInfoPrint(?MODULE, ?LINE, 100)).
-define(MEM_INFO_PRINT(Threshold), memInfoPrint(?MODULE, ?LINE, Threshold)).

-define(pdMemInfo, '$pdMemInfo').
memInfoInit(CurModule, CurLine) ->
   erlang:put(?pdMemInfo, {CurModule, CurLine, erlang:system_time(nanosecond), recon:info(self(), memory_used), erlang:memory()}).

memInfoPrint(CurModule, CurLine, Threshold) ->
   case erlang:get(?pdMemInfo) of
      undefined ->
         erlang:put(?pdMemInfo, {CurModule, CurLine, erlang:system_time(nanosecond), recon:info(self(), memory_used), erlang:memory()});
      {OldModule, OldLine, OldTime, OldMemInfo, OldSumInfo} ->
         CurMemInfo = recon:info(self(), memory_used),
         CurTime = erlang:system_time(nanosecond),
         CurSumInfo = erlang:memory(),
         erlang:put(?pdMemInfo, {CurModule, CurLine, CurTime, CurMemInfo, CurSumInfo}),
         SubPid = element(2, lists:nth(1, element(2, CurMemInfo))) - element(2, lists:nth(1, element(2, OldMemInfo))),
         SubSum = element(2, lists:keyfind(total, 1, CurSumInfo)) - element(2, lists:keyfind(total, 1, OldSumInfo)),
         case erlang:abs(SubSum) >= Threshold orelse erlang:abs(SubPid) >= Threshold of
            true ->
               io:format(
                  "IMY*********Memory use changes are too large:~n"
                  "addOrSubSum:~20w~n"
                  "addOrSubPid:~20w~n"
                  "usedTimeDiff:~19w~n"
                  "oldLine:~w~n"
                  "CurLine:~w~n"
                  "&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&\n"
                  "OldSumInfo:~w~n"
                  "CurSumInfo:~w~n"
                  "&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&&\n"
                  "OldPidInfo:~w~n"
                  "************************************************************************************~n"
                  "CurPidInfo:~w~n", [SubSum, SubPid, CurTime - OldTime, {old, OldModule, OldLine, OldTime}, {cur, CurModule, CurLine, CurTime}, OldSumInfo, CurSumInfo, OldMemInfo, CurMemInfo]);
            _ ->
               ignore
         end
   end,
   gc().

get_test() ->
   #{'$map_tab' => tb_client, black_hole => 6, bomb_drill => 7, cat_coin => 680,
      client_data => <<"{\"db_base\":{\"uid\":1006,\"talking_scene_info\":[],\"talking_data\":[]},\"db_item_list\":[[\"item_uid\",\"item_tid\",\"item_num\"],[1,1001,1006,4],[2,1002,1007,4],[3,1003,1008,4],[4,1004,1015,4],[5,1005,1016,4],[6,1006,1017,4]],\"db_inland_idip\":{\"coin_before_count\":0,\"coin_after_count\":0,\"coin_freeze_info\":0,\"coin_opt_id\":0,\"band_join_ranking_info\":[]},\"db_cat_feed\":{\"money_time\":0,\"shovel\":0,\"day_index\":0,\"accum_food_time\":0,\"money_list\":[],\"clean_frd_time\":[],\"accum_water_time\":0,\"accum_money\":0,\"water_time\":0,\"remain_water\":0,\"remain_money\":0,\"food_time\":0,\"remain_food\":0,\"first_add_money_time\":0,\"used_shovel\":0,\"last_add_day\":0},\"db_store_ad\":{\"watched_count\":0,\"next_ad_time\":0,\"today_cookie\":\"\"},\"db_level\":{\"level_item_list\":[],\"eng_infinite_tag\":0,\"flag_lv\":0,\"lv_type\":0,\"level_buy_time\":0,\"continue_cost\":0,\"activity_form\":\"\",\"lv_failn_advice\":0,\"level_state\":0,\"set_result\":0,\"use_item_list\":[],\"lv_end_gold\":false,\"lv_failed_count\":[]},\"db_data_verify\":{\"saved_index\":0,\"generate_index\":0,\"server_data_version_code\":0,\"upload_data_time\":0},\"db_timeline_stuff_style\":[],\"db_cat_map\":[],\"db_finished_activity\":[],\"db_monthcard\":{\"have_got\":false,\"day_left_os_time\":0,\"week_day\":0,\"disc_num\":0,\"card_day\":0,\"left_sec\":0,\"card_id\":0,\"day_left_time\":0,\"tag\":0,\"left_os_time\":0,\"show_monthcard_cell\":[]},\"db_logger\":{\"online_sec\":0,\"coin_cost\":0,\"use_doublerocket\":0,\"use_crosshammer\":0,\"use_bombanddril\":0,\"seed\":0,\"day_idx\":0,\"log\":0,\"use_glove\":0,\"gold_cost\":0,\"use_hammer\":0,\"use_blackhole\":0,\"day_num\":0,\"pay_num\":0,\"reshuffle\":0},\"db_role\":{\"order_id_list\":[],\"dr_infinite_left_sec\":0,\"lv_tag\":1,\"first_tlv\":true,\"login_time\":1608963650,\"energy\":5,\"lv_idx\":1,\"gold\":1000,\"login_day_count\":0,\"have_sign\":[],\"chapter\":1,\"energy_time\":0,\"spend_money\":0,\"gold_re\":0,\"bh_infinite_left_sec\":0,\"main_decorate_stuff\":0,\"server_mail_id\":0,\"token\":0,\"energy_recover_halve\":0,\"self_room_stars\":0,\"ad_remaining_num\":0,\"level\":1,\"eneryg_infinite_left_times\":0,\"bd_infinite_left_sec\":0,\"max_product_id\":0,\"play_time_sec\":0,\"last_login_day_index\":0,\"dr_infinite\":0,\"star\":0,\"bh_infinite\":0,\"cat_coin\":0,\"newplayer_signin_complete\":0,\"server_day_idx\":0,\"fb_first_award\":false,\"logout_time\":1608963650,\"special_point\":0,\"tutorial_on\":true,\"diamond\":0,\"energy_infinite\":0,\"role_name\":\"\",\"bd_infinite\":0},\"db_cat_room_map\":[],\"db_chapter_map\":[[\"chapter\",\"begin\",\"award_idx\",\"stuffs\"],{1:1,2:1,3:false,4:0,5:[]}],\"db_activity_settle\":{\"infinite_challenge_info\":[0,0,0]},\"db_cat_gift\":{\"max_award_num\":false,\"award_num\":false,\"end_ti\":0,\"first_feed_gift\":false,\"select_hour_type\":false,\"left_sec\":0,\"awards\":false,\"start_ti\":0},\"db_cat_stuff_map\":[],\"db_cat_gift_new\":{\"cur_gift\":[],\"is_unlock\":false,\"gifts\":[]},\"db_activity\":[],\"db_cat_ad\":{\"ad_num\":0,\"is_unlock\":false,\"cd_time\":0},\"db_clothes_out_cat\":[],\"db_award_map\":[],\"db_tutorial\":[],\"db_stuff_timeline\":[],\"db_inland_server\":{\"account_channel\":\"\",\"uuid\":\"\",\"channel_role\":[],\"bind_account_award\":false,\"decorate_progress\":0,\"story_progress\":0},\"db_cat_extra\":{\"unlock_list\":[]},\"db_mail_list\":[],\"db_stuff_child_visible\":[],\"db_head\":{\"show_head\":\"1\",\"own_head\":[]},\"db_cat_event\":{\"is_init\":false,\"start_time\":0,\"is_unlock\":false,\"num\":0},\"db_talking_choose\":[],\"db_process\":{\"process\":[]}}">>,
      client_idx => 170,
      client_incr =>
      [
         <<"{\"s\":{\"db_cat_feed\":{\"m\":{\"remain_food\":471.66666666667,\"food_time\":1608965030}},\"db_award_map\":{\"d\":[1077]},\"db_item_list\":{\"s\":[{\"m\":{\"item_num\":7}},{\"m\":{\"item_num\":6}},{\"m\":{\"item_num\":5}},{\"m\":{\"item_num\":5}}]},\"db_data_verify\":{\"m\":{\"generate_index\":212}},\"db_activity\":{\"s\":{5101:{\"m\":{\"_left_sec\":292567}},4001:{\"m\":{\"_left_sec\":292567}},5901:{\"m\":{\"_left_sec\":284462167}}}},\"db_role\":{\"m\":{\"energy_infinite\":1608979053,\"eneryg_infinite_left_times\":14019,\"logout_time\":1608965030,\"play_time_sec\":1380}}}}">>,
         <<"{\"s\":{\"db_base\":{\"m\":{\"uid\":1080}},\"db_activity\":{\"s\":{5101:{\"m\":{\"_start_ti\":1608965020,\"_left_sec\":292574}},4001:{\"m\":{\"_start_ti\":1608965020,\"_left_sec\":292574}},5901:{\"m\":{\"_start_ti\":1608965020,\"_left_sec\":284462174}}},\"d\":[2001]},\"db_level\":{\"m\":{\"lv_end_gold\":false}},\"db_data_verify\":{\"m\":{\"generate_index\":211}},\"db_finished_activity\":{\"m\":{2001:true}},\"db_role\":{\"m\":{\"gold\":6416}}}}">>,
         <<"{\"s\":{\"db_base\":{\"m\":{\"uid\":1079}},\"db_award_map\":{\"m\":{1077:{\"item_award_index\":[[2089,[1,2,3,4,5]]],\"item_num\":1,\"goods_id\":0,\"reason\":13,\"cost_num\":0,\"uid\":1077,\"opt_info\":[2001,3],\"awards\":[[2024,120],[1006,1],[1007,1],[1008,1],[1015,1]],\"cost_currency\":0}}},\"db_data_verify\":{\"m\":{\"generate_index\":210}},\"db_activity\":{\"s\":{2001:{\"m\":{\"level_point_got\":12}}}},\"db_item_list\":{\"m\":{7:{\"item_uid\":1079,\"item_tid\":1019,\"item_num\":1}}}}}">>,
         <<"{\"s\":{\"db_data_verify\":{\"m\":{\"generate_index\":209}}}}">>,
         <<"{\"s\":{\"db_data_verify\":{\"m\":{\"generate_index\":208}},\"db_activity\":{\"s\":{5101:{\"m\":{\"score\":2}}}}}}">>,
         <<"{\"s\":{\"db_data_verify\":{\"m\":{\"generate_index\":207}}}}">>,
         <<"{\"s\":{\"db_data_verify\":{\"m\":{\"generate_index\":206}}}}">>,
         <<"{\"s\":{\"db_data_verify\":{\"m\":{\"generate_index\":205}}}}">>,
         <<"{\"s\":{\"db_base\":{\"m\":{\"uid\":1076}},\"db_data_verify\":{\"m\":{\"generate_index\":204}},\"db_role\":{\"m\":{\"star\":1,\"cat_coin\":680,\"gold\":6393}}}}">>,
         <<"{\"s\":{\"db_logger\":{\"m\":{\"seed\":769916928}},\"db_level\":{\"m\":{\"lv_end_gold\":true,\"flag_lv\":31}},\"db_data_verify\":{\"m\":{\"generate_index\":203}},\"db_activity\":{\"s\":{2001:{\"m\":{\"_left_sec\":206181}},5101:{\"m\":{\"_left_sec\":292581}},4001:{\"m\":{\"_left_sec\":292581}},5901:{\"m\":{\"_left_sec\":284462181}}}},\"db_role\":{\"m\":{\"logout_time\":1608965020,\"level\":32,\"lv_tag\":32,\"lv_idx\":32,\"play_time_sec\":1370}}}}">>,
         <<"{\"s\":{\"db_base\":{\"s\":{\"talking_data\":{\"m\":{20122:[],1071:[]}}}},\"db_talking_choose\":{\"m\":{\"20008-1\":true}},\"db_tutorial\":{\"m\":{138:true}},\"db_inland_server\":{\"m\":{\"decorate_progress\":23,\"story_progress\":37}},\"db_cat_gift_new\":{\"s\":{\"cur_gift\":{\"m\":{\"gift_id\":8022,\"end_time\":1608993795}},\"gifts\":{\"s\":[{\"m\":{\"index\":2,\"gift_id\":8020}},{\"m\":{\"index\":3,\"gift_id\":8021}}],\"d\":[3]}}},\"db_data_verify\":{\"m\":{\"generate_index\":202}},\"db_activity\":{\"s\":{2001:{\"m\":{\"_left_sec\":206191}},5101:{\"m\":{\"_left_sec\":292591}},4001:{\"m\":{\"_left_sec\":292591}},5901:{\"m\":{\"_left_sec\":284462191}}}},\"db_role\":{\"m\":{\"logout_time\":1608965000,\"main_decorate_stuff\":212,\"play_time_sec\":1350}}}}">>,
         <<"{\"s\":{\"db_cat_feed\":{\"m\":{\"remain_food\":472.66666666667,\"food_time\":1608964970}},\"db_chapter_map\":{\"s\":{2:{\"s\":{\"stuffs\":{\"m\":{212:{\"stuff_id\":212,\"select_id\":1}}}}}}},\"db_data_verify\":{\"m\":{\"generate_index\":201}},\"db_activity\":{\"s\":{2001:{\"m\":{\"_left_sec\":206221}},5101:{\"m\":{\"_left_sec\":292621}},4001:{\"m\":{\"_left_sec\":292621}},5901:{\"m\":{\"_left_sec\":284462221}}}},\"db_role\":{\"m\":{\"logout_time\":1608964970,\"star\":0,\"play_time_sec\":1320}}}}">>,
         <<"{\"s\":{\"db_base\":{\"m\":{\"uid\":1075}},\"db_level\":{\"m\":{\"lv_end_gold\":false}},\"db_data_verify\":{\"m\":{\"generate_index\":200}},\"db_activity\":{\"s\":{2001:{\"m\":{\"_start_ti\":1608964959,\"_left_sec\":206232,\"level_point_got\":11}},5101:{\"m\":{\"_start_ti\":1608964959,\"_left_sec\":292632}},4001:{\"m\":{\"_start_ti\":1608964959,\"_left_sec\":292632}},5901:{\"m\":{\"_start_ti\":1608964959,\"_left_sec\":284462232}}}},\"db_role\":{\"m\":{\"logout_time\":1608964960,\"play_time_sec\":1310,\"gold\":6343}}}}">>,
         <<"{\"s\":{\"db_data_verify\":{\"m\":{\"generate_index\":199}}}}">>,
         <<"{\"s\":{\"db_data_verify\":{\"m\":{\"generate_index\":198}},\"db_activity\":{\"s\":{5101:{\"m\":{\"score\":1}}}}}}">>,
         <<"{\"s\":{\"db_data_verify\":{\"m\":{\"generate_index\":197}}}}">>,
         <<"{\"s\":{\"db_data_verify\":{\"m\":{\"generate_index\":196}},\"db_activity\":{\"s\":{4001:{\"s\":{\"materials\":{\"m\":{132422520:40}}}}}}}}">>,
         <<"{\"s\":{\"db_data_verify\":{\"m\":{\"generate_index\":195}}}}">>,
         <<"{\"s\":{\"db_base\":{\"m\":{\"uid\":1074}},\"db_data_verify\":{\"m\":{\"generate_index\":194}},\"db_role\":{\"m\":{\"star\":2,\"cat_coin\":660,\"gold\":6317}}}}">>,
         <<"{\"s\":{\"db_logger\":{\"m\":{\"seed\":1921384448}},\"db_level\":{\"m\":{\"lv_end_gold\":true,\"flag_lv\":30}},\"db_data_verify\":{\"m\":{\"generate_index\":193}},\"db_activity\":{\"s\":{2001:{\"m\":{\"_left_sec\":206242}},5101:{\"m\":{\"_left_sec\":292642}},4001:{\"m\":{\"_left_sec\":292642}},5901:{\"m\":{\"_left_sec\":284462242}}}},\"db_role\":{\"m\":{\"level\":31,\"lv_tag\":31,\"lv_idx\":31}}}}">>,
         <<"{\"s\":{\"db_base\":{\"s\":{\"talking_data\":{\"m\":{1039:[]}}}},\"db_inland_server\":{\"m\":{\"story_progress\":35}},\"db_tutorial\":{\"m\":{125:true}},\"db_data_verify\":{\"m\":{\"generate_index\":192}},\"db_activity\":{\"s\":{2001:{\"m\":{\"_left_sec\":206249}},5101:{\"m\":{\"_end_ti\":1609257600,\"_left_sec\":292649}},4001:{\"m\":{\"_left_sec\":292649}},5901:{\"m\":{\"_left_sec\":284462249}}}},\"db_role\":{\"m\":{\"logout_time\":1608964950,\"play_time_sec\":1300}}}}">>,
         <<"{\"s\":{\"db_data_verify\":{\"m\":{\"generate_index\":191}},\"db_activity\":{\"s\":{4001:{\"m\":{\"_left_sec\":292656}},5901:{\"m\":{\"_left_sec\":284462256}},2001:{\"m\":{\"_left_sec\":206256}}},\"m\":{5101:{\"fb_start\":true,\"progress\":0,\"_start_ti\":1608964944,\"_end_ti\":1609257626,\"score\":0,\"_left_sec\":292682}}}}}">>,
         <<"{\"s\":{\"db_base\":{\"m\":{\"uid\":1073}},\"db_data_verify\":{\"m\":{\"generate_index\":190}},\"db_activity\":{\"s\":{4001:{\"s\":{\"order_list\":{\"s\":[{\"s\":{\"ice_cream_list\":{\"d\":[1]}},\"m\":{\"end_time\":1608966135,\"id\":2001}}]}},\"m\":{\"_left_sec\":292659,\"interval\":0,\"progress\":1}},5901:{\"m\":{\"_left_sec\":284462259}},2001:{\"m\":{\"_left_sec\":206259}}}},\"db_role\":{\"m\":{\"logout_time\":1608964940,\"play_time_sec\":1290,\"gold\":6267}}}}">>,
         <<"{\"s\":{\"db_data_verify\":{\"m\":{\"generate_index\":189}},\"db_activity\":{\"s\":{4001:{\"s\":{\"materials\":{\"m\":{-884040730:0}},\"order_list\":{\"s\":[{\"s\":{\"ice_cream_list\":{\"m\":[1]}}}]}},\"m\":{\"_left_sec\":292666}},5901:{\"m\":{\"_left_sec\":284462266}},2001:{\"m\":{\"_left_sec\":206266}}}}}}">>,
         <<"{\"s\":{\"db_base\":{\"s\":{\"talking_data\":{\"m\":{1020:[]}}},\"m\":{\"uid\":1072}},\"db_inland_server\":{\"m\":{\"story_progress\":34}},\"db_tutorial\":{\"m\":{122:true}},\"db_data_verify\":{\"m\":{\"generate_index\":188}},\"db_activity\":{\"s\":{4001:{\"s\":{\"materials\":{\"m\":{-884040730:120}}},\"m\":{\"_end_ti\":1609257600,\"_left_sec\":292669}},5901:{\"m\":{\"_left_sec\":284462269}},2001:{\"m\":{\"_left_sec\":206269}}}}}}">>,
         <<"{\"s\":{\"db_data_verify\":{\"m\":{\"generate_index\":187}},\"db_activity\":{\"s\":{2001:{\"m\":{\"_left_sec\":206270}},5901:{\"m\":{\"_left_sec\":284462270}}},\"m\":{4001:{\"_end_ti\":1609257612,\"progress_award\":[],\"order_list\":[{\"id\":1001,\"ice_cream_list\":[]},{\"id\":1006,\"ice_cream_list\":[]},{\"id\":1004,\"ice_cream_list\":[]}],\"_left_sec\":292682,\"_start_ti\":1608964930,\"materials\":{132422520:0,-884040730:0,-1047817473:0},\"fb_start\":true,\"interval\":5,\"progress\":0}}},\"db_role\":{\"m\":{\"logout_time\":1608964930,\"play_time_sec\":1280}}}}">>,
         <<"{\"s\":{\"db_base\":{\"m\":{\"uid\":1071}},\"db_level\":{\"m\":{\"lv_end_gold\":false}},\"db_data_verify\":{\"m\":{\"generate_index\":186}},\"db_activity\":{\"s\":{2001:{\"m\":{\"_start_ti\":1608964918,\"_left_sec\":206278,\"level_point_got\":10}},5901:{\"m\":{\"_start_ti\":1608964918,\"_left_sec\":284462278}}}},\"db_role\":{\"m\":{\"logout_time\":1608964920,\"play_time_sec\":1270,\"gold\":6262}}}}">>,
         <<"{\"s\":{\"db_data_verify\":{\"m\":{\"generate_index\":185}},\"db_cat_gift_new\":{\"s\":{\"gifts\":{\"m\":[{\"index\":1,\"cat_id\":0,\"gift_id\":8022},{\"index\":2,\"cat_id\":0,\"gift_id\":8020},{\"index\":3,\"cat_id\":0,\"gift_id\":8021}]}},\"m\":{\"is_unlock\":true}}}}">>,
         <<"{\"s\":{\"db_base\":{\"m\":{\"uid\":1070}},\"db_data_verify\":{\"m\":{\"generate_index\":184}},\"db_role\":{\"m\":{\"star\":1,\"cat_coin\":640,\"gold\":6230}}}}">>,
         <<"{\"s\":{\"db_cat_feed\":{\"m\":{\"remain_food\":473.66666666667,\"food_time\":1608964910}},\"db_logger\":{\"m\":{\"seed\":843841536}},\"db_level\":{\"m\":{\"lv_end_gold\":true,\"flag_lv\":29}},\"db_data_verify\":{\"m\":{\"generate_index\":183}},\"db_activity\":{\"s\":{2001:{\"m\":{\"_left_sec\":206284}},5901:{\"m\":{\"_left_sec\":284462284}}}},\"db_role\":{\"m\":{\"logout_time\":1608964910,\"level\":30,\"lv_tag\":30,\"lv_idx\":30,\"play_time_sec\":1260}}}}">>,
         <<"{\"s\":{\"db_base\":{\"s\":{\"talking_data\":{\"m\":{20112:[]}}}},\"db_inland_server\":{\"m\":{\"decorate_progress\":22,\"story_progress\":33}},\"db_data_verify\":{\"m\":{\"generate_index\":182}},\"db_activity\":{\"s\":{2001:{\"m\":{\"_left_sec\":206290}},5901:{\"m\":{\"_left_sec\":284462290}}}},\"db_role\":{\"m\":{\"main_decorate_stuff\":211}}}}">>,
         <<"{\"s\":{\"db_chapter_map\":{\"s\":{2:{\"s\":{\"stuffs\":{\"m\":{211:{\"stuff_id\":211,\"select_id\":1}}}}}}},\"db_data_verify\":{\"m\":{\"generate_index\":181}},\"db_activity\":{\"s\":{2001:{\"m\":{\"_left_sec\":206296}},5901:{\"m\":{\"_left_sec\":284462296}}}},\"db_role\":{\"m\":{\"logout_time\":1608964900,\"star\":0,\"play_time_sec\":1250}}}}">>,
         <<"{\"s\":{\"db_base\":{\"m\":{\"uid\":1069}},\"db_level\":{\"m\":{\"lv_end_gold\":false}},\"db_data_verify\":{\"m\":{\"generate_index\":180}},\"db_activity\":{\"s\":{2001:{\"m\":{\"_start_ti\":1608964886,\"_left_sec\":206310,\"level_point_got\":9,\"_end_ti\":1609171200}},5901:{\"m\":{\"_end_ti\":1893427200,\"_left_sec\":284462310,\"_start_ti\":1608964886}}}},\"db_role\":{\"m\":{\"gold\":6180}}}}">>,
         <<"{\"s\":{\"db_data_verify\":{\"m\":{\"generate_index\":179}}}}">>,
         <<"{\"s\":{\"db_base\":{\"m\":{\"uid\":1068}},\"db_data_verify\":{\"m\":{\"generate_index\":178}},\"db_role\":{\"m\":{\"star\":2,\"cat_coin\":620,\"gold\":6154}}}}">>,
         <<"{\"s\":{\"db_logger\":{\"m\":{\"seed\":-1575354368}},\"db_level\":{\"m\":{\"lv_end_gold\":true,\"flag_lv\":28}},\"db_data_verify\":{\"m\":{\"generate_index\":177}},\"db_activity\":{\"s\":{2001:{\"m\":{\"_left_sec\":206314}},5901:{\"m\":{\"_left_sec\":284462314}}}},\"db_role\":{\"m\":{\"logout_time\":1608964881,\"level\":29,\"lv_tag\":29,\"lv_idx\":29,\"play_time_sec\":1231}}}}">>,
         <<"{\"s\":{\"db_base\":{\"s\":{\"talking_data\":{\"m\":{20102:[]}}}},\"db_inland_server\":{\"m\":{\"decorate_progress\":21,\"story_progress\":32}},\"db_data_verify\":{\"m\":{\"generate_index\":176}},\"db_activity\":{\"s\":{2001:{\"m\":{\"_left_sec\":206322}},5901:{\"m\":{\"_left_sec\":284462322}}}},\"db_role\":{\"m\":{\"main_decorate_stuff\":210}}}}">>,
         <<"{\"s\":{\"db_chapter_map\":{\"s\":{2:{\"s\":{\"stuffs\":{\"m\":{210:{\"stuff_id\":210,\"select_id\":1}}}}}}},\"db_data_verify\":{\"m\":{\"generate_index\":175}},\"db_activity\":{\"s\":{2001:{\"m\":{\"_left_sec\":206328}},5901:{\"m\":{\"_left_sec\":284462328}}}},\"db_role\":{\"m\":{\"logout_time\":1608964870,\"star\":1,\"play_time_sec\":1220}}}}">>,
         <<"{\"s\":{\"db_base\":{\"m\":{\"uid\":1067}},\"db_level\":{\"m\":{\"lv_end_gold\":false}},\"db_data_verify\":{\"m\":{\"generate_index\":174}},\"db_activity\":{\"s\":{2001:{\"m\":{\"_start_ti\":1608964853,\"_left_sec\":206344,\"level_point_got\":8,\"_end_ti\":1609171201}},5901:{\"m\":{\"_end_ti\":1893427201,\"_left_sec\":284462344,\"_start_ti\":1608964853}}}},\"db_role\":{\"m\":{\"gold\":6104}}}}">>,
         <<"{\"s\":{\"db_data_verify\":{\"m\":{\"generate_index\":173}}}}">>,
         <<"{\"s\":{\"db_base\":{\"m\":{\"uid\":1066}},\"db_data_verify\":{\"m\":{\"generate_index\":172}},\"db_role\":{\"m\":{\" star\":2,\"cat_coin\":600,\"gold\":6078}}}}">>,
         <<"{\"s\":{\"db_cat_feed\":{\"m\":{\"remain_food\":474.66666666667,\"food_time\":1608964850}},\"db_logger\":{\"m\":{\"seed\":1389625344}},\"db_level\":{\"m\":{\"lv_end_gold\":true,\"flag_lv\":27}},\"db_data_verify\":{\"m\":{\"saved_index\":170,\"generate_index\":171,\"upload_data_time\":1608964850}},\"db_activity\":{\"s\":{2001:{\"m\":{\"_left_sec\":206349}},5901:{\"m\":{\"_left_sec\":284462349}}}},\"db_role\":{\"m\":{\"logout_time\":1608964850,\"level\":28,\"lv_tag\":28,\"lv_idx\":28,\"play_time_sec\":1200}}}}">>,
         <<"{\"s\":{\"db_base\":{\"s\":{\"talking_data\":{\"m\":{1068:[],20092:[]}}}},\"db_inland_server\":{\"m\":{\"decorate_progress\":20,\"story_progress\":31}},\"db_tutorial\":{\"m\":{133:true}},\"db_data_verify\":{\"m\":{\"generate_index\":170}},\"db_activity\":{\"s\":{2001:{\"m\":{\"_left_sec\":206355}},5901:{\"m\":{\"_left_sec\":284462355}}}},\"db_role\":{\"m\":{\"logout_time\":1608964840,\"main_decorate_stuff\":209,\"play_time_sec\":1190}}}}">>,
         <<"{\"s\":{\"db_chapter_map\":{\"s\":{2:{\"s\":{\"stuffs\":{\"m\":{209:{\"stuff_id\":209,\"select_id\":1}}}}}}},\"db_data_verify\":{\"m\":{\"generate_index\":169}},\"db_activity\":{\"s\":{2001:{\"m\":{\"_left_sec\":206368}},5901:{\"m\":{\"_left_sec\":284462368}}}},\"db_role\":{\"m\":{\"logout_time\":1608964830,\"star\":1,\"play_time_sec\":1180}}}}">>,
         <<"{\"s\":{\"db_base\":{\"s\":{\"talking_data\":{\"m\":{20082:[]}}},\"m\":{\"uid\":1065}},\"db_chapter_map\":{\"s\":{2:{\"m\":{\"award_idx\":2}}}},\"db_talking_choose\":{\"m\":{\"20007-1\":true}},\"db_item_list\":{\"s\":[{\"m\":{\"item_num\":6}}]},\"db_inland_server\":{\"m\":{\"decorate_progress\":19,\"story_progress\":29}},\"db_data_verify\":{\"m\":{\"generate_index\":168}},\"db_activity\":{\"s\":{2001:{\"m\":{\"_left_sec\":206371}},5901:{\"m\":{\"_left_sec\":284462371}}}},\"db_role\":{\"m\":{\"energy_infinite\":1608971853,\"cat_coin\":580,\"logout_time\":1608964820,\"eneryg_infinite_left_times\":7024,\"main_decorate_stuff\":208,\"play_time_sec\":1170}}}}">>,
         <<"{\"s\":{\"db_chapter_map\":{\"s\":{2:{\"s\":{\"stuffs\":{\"m\":{208:{\"stuff_id\":208,\"select_id\":1}}}}}}},\"db_data_verify\":{\"m\":{\"generate_index\":167}},\"db_activity\":{\"s\":{2001:{\"m\":{\"_left_sec\":206382}},5901:{\"m\":{\"_left_sec\":284462382}}}},\"db_role\":{\"m\":{\"logout_time\":1608964810,\"star\":3,\"play_time_sec\":1160}}}}">>,
         <<"{\"s\":{\"db_base\":{\"m\":{\"uid\":1064}},\"db_level\":{\"m\":{\"lv_end_gold\":false}},\"db_data_verify\":{\"m\":{\"generate_index\":166}},\"db_activity\":{\"s\":{2001:{\"m\":{\"_start_ti\":1608964803,\"_left_sec\":206393,\"level_point_got\":7,\"_end_ti\":1609171200}},5901:{\"m\":{\"_end_ti\":1893427200,\"_left_sec\":284462393,\"_start_ti\":1608964803}}}},\"db_role\":{\"m\":{\"gold\":6028}}}}">>,
         <<"{\"s\":{\"db_data_verify\":{\"m\":{\"generate_index\":165}}}}">>,
         <<"{\"s\":{\"db_base\":{\"m\":{\"uid\":1063}},\"db_data_verify\":{\"m\":{\"generate_index\":164}},\"db_role\":{\"m\":{\"star\":5,\"cat_coin\":480,\"gold\":6003}}}}">>,
         <<"{\"s\":{\"db_level\":{\"m\":{\"lv_end_gold\":true,\"flag_lv\":26}},\"db_logger\":{\"m\":{\"seed\":-1132199936}},\"db_tutorial\":{\"m\":{13:true}},\"db_data_verify\":{\"m\":{\"generate_index\":163}},\"db_activity\":{\"s\":{2001:{\"m\":{\"_left_sec\":206399}},5901:{\"m\":{\"_left_sec\":284462399}}}},\"db_role\":{\"m\":{\"logout_time\":1608964800,\"level\":27,\"lv_tag\":27,\"lv_idx\":27,\"play_time_sec\":1150}}}}">>,
         <<"{\"s\":{\"db_cat_feed\":{\"m\":{\"remain_food\":475.66666666667,\"food_time\":1608964790}},\"db_data_verify\":{\"m\":{\"generate_index\":162}},\"db_activity\":{\"s\":{2001:{\"m\":{\"_left_sec\":206409}},5901:{\"m\":{\"_left_sec\":284462409}}}},\"db_role\":{\"m\":{\"logout_time\":1608964790,\"play_time_sec\":1140}}}}">>,
         <<"{\"s\":{\"db_data_verify\":{\"m\":{\"generate_index\":161}},\"db_award_map\":{\"d\":[1061]},\"db_item_list\":{\"s\":[{\"m\":{\"item_num\":5}},{\"m\":{\"item_num\":5}}]},\"db_activity\":{\"s\":{2001:{\"m\":{\"_left_sec\":206415}},5901:{\"m\":{\"_left_sec\":284462415}}}},\"db_role\":{\"m\":{\"energy_infinite\":1608970053,\"eneryg_infinite_left_times\":5267,\"logout_time\":1608964780,\"play_time_sec\":1130}}}}">>,
         <<"{\"s\":{\"db_base\":{\"m\":{\"uid\":1062}},\"db_award_map\":{\"m\":{1061:{\"item_award_index\":[[2088,[1,2,3]]],\"item_num\":1,\"goods_id\":0,\"reason\":13,\"cost_num\":0,\"uid\":1061,\"opt_info\":[2001,2],\"awards\":[[2024,60],[1006,1],[1007,1]],\"cost_currency\":0}}},\"db_level\":{\"m\":{\"lv_end_gold\":false}},\"db_data_verify\":{\"m\":{\"generate_index\":160}},\"db_activity\":{\"s\":{2001:{\"m\":{\"_start_ti\":1608964775,\"_left_sec\":206423,\"level_point_got\":6,\"_end_ti\":1609171201}},5901:{\"m\":{\"_end_ti\":1893427201,\"_left_sec\":284462423,\"_start_ti\":1608964775}}}},\"db_role\":{\"m\":{\"gold\":5953}}}}">>,
         <<"{\"s\":{\"db_data_verify\":{\"m\":{\"generate_index\":159}}}}">>,
         <<"{\"s\":{\"db_base\":{\"m\":{\"uid\":1060}},\"db_data_verify\":{\"m\":{\"generate_index\":158}},\"db_role\":{\"m\":{\"star\":4,\"cat_coin\":460,\"gold\":5927}}}}">>,
         <<"{\"s\":{\"db_logger\":{\"m\":{\"seed\":-875036672}},\"db_level\":{\"m\":{\"lv_end_gold\":true,\"flag_lv\":25}},\"db_data_verify\":{\"m\":{\"generate_index\":157}},\"db_activity\":{\"s\":{2001:{\"m\":{\"_left_sec\":206425}},5901:{\"m\":{\"_left_sec\":284462425}}}},\"db_role\":{\"m\":{\"logout_time\":1608964770,\"level\":26,\"lv_tag\":26,\"lv_idx\":26,\"play_time_sec\":1120}}}}">>,
         <<"{\"s\":{\"db_data_verify\":{\"m\":{\"generate_index\":156}},\"db_activity\":{\"s\":{2001:{\"m\":{\"_left_sec\":206440}},5901:{\"m\":{\"_left_sec\":284462440}}}},\"db_role\":{\"m\":{\"logout_time\":1608964760,\"play_time_sec\":1110}}}}">>,
         <<"{\"s\":{\"db_base\":{\"m\":{\"uid\":1059}},\"db_level\":{\"m\":{\"lv_end_gold\":false}},\"db_data_verify\":{\"m\":{\"generate_index\":155}},\"db_activity\":{\"s\":{2001:{\"m\":{\"_start_ti\":1608964747,\"_left_sec\":206449,\"level_point_got\":5}},5901:{\"m\":{\"_start_ti\":1608964747,\"_left_sec\":284462449}}}},\"db_role\":{\"m\":{\"logout_time\":1608964750,\"play_time_sec\":1100,\"gold\":5877}}}}">>,
         <<"{\"s\":{\"db_data_verify\":{\"m\":{\"generate_index\":154}}}}">>,
         <<"{\"s\":{\"db_base\":{\"m\":{\"uid\":1058}},\"db_data_verify\":{\"m\":{\"generate_index\":153}},\"db_role\":{\"m\":{\"star\":3,\"cat_coin\":440,\"gold\":5856}}}}">>,
         <<"{\"s\":{\"db_level\":{\"m\":{\"lv_end_gold\":true,\"flag_lv\":24}},\"db_logger\":{\"m\":{\"seed\":502792192}},\"db_tutorial\":{\"m\":{8:true}},\"db_data_verify\":{\"m\":{\"generate_index\":152}},\"db_activity\":{\"s\":{2001:{\"m\":{\"_left_sec\":206455}},5901:{\"m\":{\"_left_sec\":284462455}}}},\"db_role\":{\"m\":{\"logout_time\":1608964741,\"level\":25,\"lv_tag\":25,\"lv_idx\":25,\"play_time_sec\":1091}}}}">>,
         <<"{\"s\":{\"db_cat_feed\":{\"m\":{\"remain_food\":476.66666666667,\"food_time\":1608964730}},\"db_data_verify\":{\"m\":{\"generate_index\":151}},\"db_activity\":{\"s\":{2001:{\"m\":{\"_left_sec\":206463}},5901:{\"m\":{\"_left_sec\":284462463}}}},\"db_role\":{\"m\":{\"logout_time\":1608964730,\"play_time_sec\":1080}}}}">>,
         <<"{\"s\":{\"db_base\":{\"m\":{\"uid\":1057}},\"db_level\":{\"m\":{\"lv_end_gold\":false}},\"db_data_verify\":{\"m\":{\"generate_index\":150}},\"db_activity\":{\"s\":{2001:{\"m\":{\"_start_ti\":1608964725,\"_left_sec\":206472,\"level_point_got\":4}},5901:{\"m\":{\"_start_ti\":1608964725,\"_left_sec\":284462472}}}},\"db_role\":{\"m\":{\"gold\":5806}}}}">>,
         <<"{\"s\":{\"db_data_verify\":{\"m\":{\"generate_index\":149}}}}">>,
         <<"{\"s\":{\"db_base\":{\"m\":{\"uid\":1056}},\"db_data_verify\":{\"m\":{\"generate_index\":148}},\"db_role\":{\"m\":{\"star\":2,\"cat_coin\":420,\"gold\":5777}}}}">>,
         <<"{\"s\":{\"db_logger\":{\"m\":{\"seed\":153092096}},\"db_level\":{\"m\":{\"lv_end_gold\":true,\"flag_lv\":23}},\"db_data_verify\":{\"m\":{\"generate_index\":147}},\"db_activity\":{\"s\":{2001:{\"m\":{\"_left_sec\":206477}},5901:{\"m\":{\"_left_sec\":284462477}}}},\"db_role\":{\"m\":{\"logout_time\":1608964720,\"level\":24,\"lv_tag\":24,\"lv_idx\":24,\"play_time_sec\":1070}}}}">>,
         <<"{\"s\":{\"db_base\":{\"s\":{\"talking_data\":{\"m\":{20072:[],1067:[]}}}},\"db_inland_server\":{\"m\":{\"decorate_progress\":18,\"story_progress\":28}},\"db_tutorial\":{\"m\":{132:true}},\"db_data_verify\":{\"m\":{\"generate_index\":146}},\"db_activity\":{\"s\":{2001:{\"m\":{\"_left_sec\":206482}},5901:{\"m\":{\"_left_sec\":284462482}}}},\"db_role\":{\"m\":{\"logout_time\":1608964710,\"main_decorate_stuff\":207,\"play_time_sec\":1060}},\"db_cat_room_map\":{\"s\":{2001:{\"s\":{\"cat_id_list\":{\"m\":{2:4003}}}}}}}}">>,
         <<"{\"s\":{\"db_base\":{\"s\":{\"talking_data\":{\"m\":{20062:[]}}}},\"db_inland_server\":{\"m\":{\"decorate_progress\":17,\"story_progress\":26}},\"db_talking_choose\":{\"m\":{\"20006-1\":true,\"20005-1\":true}},\"db_chapter_map\":{\"s\":{2:{\"s\":{\"stuffs\":{\"m\":{207:{\"stuff_id\":207,\"select_id\":1}}}}}}},\"db_data_verify\":{\"m\":{\"generate_index\":145}},\"db_activity\":{\"s\":{2001:{\"m\":{\"_left_sec\":206498}},5901:{\"m\":{\"_left_sec\":284462498}}}},\"db_role\":{\"m\":{\"logout_time\":1608964700,\"star\":1,\"main_decorate_stuff\":206,\"play_time_sec\":1050}}}}">>,
         <<"{\"s\":{\"db_base\":{\"s\":{\"talking_data\":{\"m\":{20052:[]}}}},\"db_inland_server\":{\"m\":{\"decorate_progress\":16,\"story_progress\":25}},\"db_chapter_map\":{\"s\":{2:{\"s\":{\"stuffs\":{\"m\":{206:{\"stuff_id\":206,\"select_id\":0}}}}}}},\"db_data_verify\":{\"m\":{\"generate_index\":144}},\"db_activity\":{\"s\":{2001:{\"m\":{\"_left_sec\":206510}},5901:{\"m\":{\"_left_sec\":284462510}}}},\"db_role\":{\"m\":{\"logout_time\":1608964690,\"star\":3,\"main_decorate_stuff\":205,\"play_time_sec\":1040}}}}">>,
         <<"{\"s\":{\"db_chapter_map\":{\"s\":{2:{\"s\":{\"stuffs\":{\"m\":{205:{\"stuff_id\":205,\"select_id\":1}}}}}}},\"db_data_verify\":{\"m\":{\"generate_index\":143}},\"db_activity\":{\"s\":{2001:{\"m\":{\"_left_sec\":206516}},5901:{\"m\":{\"_left_sec\":284462516}}}},\"db_role\":{\"m\":{\"logout_time\":1608964680,\"star\":5,\"play_time_sec\":1030}}}}">>,
         <<"{\"s\":{\"db_cat_feed\":{\"m\":{\"remain_food\":477.66666666667,\"food_time\":1608964670}},\"db_base\":{\"m\":{\"uid\":1055}},\"db_level\":{\"m\":{\"lv_end_gold\":false}},\"db_data_verify\":{\"m\":{\"generate_index\":142}},\"db_activity\":{\"s\":{2001:{\"m\":{\"_start_ti\":1608964668,\"_left_sec\":206528,\"level_point_got\":3}},5901:{\"m\":{\"_start_ti\":1608964668,\"_left_sec\":284462528}}}},\"db_role\":{\"m\":{\"logout_time\":1608964670,\"play_time_sec\":1020,\"gold\":5727}}}}">>,
         <<"{\"s\":{\"db_data_verify\":{\"m\":{\"generate_index\":141}}}}">>,
         <<"{\"s\":{\"db_base\":{\"m\":{\"uid\":1054}},\"db_data_verify\":{\"m\":{\"generate_index\":140}},\"db_role\":{\"m\":{\"star\":7,\"cat_coin\":400,\"gold\":5702}}}}">>,
         <<"{\"s\":{\"db_logger\":{\"m\":{\"seed\":958398464}},\"db_level\":{\"m\":{\"eng_infinite_tag\":true,\"lv_end_gold\":true,\"flag_lv\":22}},\"db_data_verify\":{\"m\":{\"generate_index\":139}},\"db_activity\":{\"s\":{2001:{\"m\":{\"_left_sec\":206533}},5901:{\"m\":{\"_left_sec\":284462533}}}},\"db_role\":{\"m\":{\"logout_time\":1608964660,\"level\":23,\"lv_tag\":23,\"lv_idx\":23,\"play_time_sec\":1010}}}}">>,
         <<"{\"s\":{\"db_data_verify\":{\"m\":{\"generate_index\":138}},\"db_activity\":{\"s\":{2001:{\"m\":{\"_left_sec\":206541}},5901:{\"m\":{\"_left_sec\":284462541}}}}}}">>,
         <<"{\"s\":{\"db_award_map\":{\"d\":[1052]},\"db_data_verify\":{\"m\":{\"generate_index\":137}},\"db_activity\":{\"s\":{2001:{\"m\":{\"_left_sec\":206547}},5901:{\"m\":{\"_left_sec\":284462547}}}},\"db_role\":{\"m\":{\"energy_infinite\":1608966453,\"eneryg_infinite_left_times\":1800,\"logout_time\":1608964650,\"play_time_sec\":1000}}}}">>,
         <<"{\"s\":{\"db_base\":{\"m\":{\"uid\":1053}},\"db_award_map\":{\"m\":{1052:{\"item_award_index\":[[2087,[1]]],\"item_num\":1,\"goods_id\":0,\"reason\":13,\"cost_num\":0,\"uid\":1052,\"opt_info\":[2001,1],\"awards\":[[2024,30]],\"cost_currency\":0}}},\"db_level\":{\"m\":{\"lv_end_gold\":false}},\"db_data_verify\":{\"m\":{\"generate_index\":136}},\"db_activity\":{\"s\":{2001:{\"m\":{\"_start_ti\":1608964642,\"_left_sec\":206553,\"level_point_got\":2}},5901:{\"m\":{\"_start_ti\":1608964642,\"_left_sec\":284462553}}}},\"db_role\":{\"m\":{\"gold\":5652}}}}">>,
         <<"{\"s\":{\"db_data_verify\":{\"m\":{\"generate_index\":135}}}}">>,
         <<"{\"s\":{\"db_base\":{\"m\":{\"uid\":1051}},\"db_data_verify\":{\"m\":{\"generate_index\":134}},\"db_role\":{\"m\":{\"star\":6,\"cat_coin\":380,\"gold\":5628}}}}">>,
         <<"{\"s\":{\"db_level\":{\"m\":{\"lv_end_gold\":true,\"flag_lv\":21}},\"db_logger\":{\"m\":{\"seed\":954204160}},\"db_tutorial\":{\"m\":{55:true}},\"db_data_verify\":{\"m\":{\"generate_index\":133}},\"db_activity\":{\"s\":{2001:{\"m\":{\"_left_sec\":206559}},5901:{\"m\":{\"_left_sec\":284462559}}}},\"db_role\":{\"m\":{\"logout_time\":1608964640,\"level\":22,\"lv_tag\":22,\"lv_idx\":22,\"play_time_sec\":990}}}}">>,
         <<"{\"s\":{\"db_data_verify\":{\"m\":{\"generate_index\":132}},\"db_activity\":{\"s\":{2001:{\"m\":{\"_left_sec\":206568}},5901:{\"m\":{\"_left_sec\":284462568}}}},\"db_role\":{\"m\":{\"logout_time\":1608964630,\"play_time_sec\":980}}}}">>,
         <<"{\"s\":{\"db_base\":{\"m\":{\"uid\":1050}},\"db_level\":{\"m\":{\"lv_end_gold\":false}},\"db_data_verify\":{\"m\":{\"generate_index\":131}},\"db_activity\":{\"s\":{2001:{\"m\":{\"_start_ti\":1608964616,\"_left_sec\":206578,\"level_point_got\":1}},5901:{\"m\":{\"_start_ti\":1608964616,\"_left_sec\":284462578}}}},\"db_role\":{\"m\":{\"logout_time\":1608964620,\"play_time_sec\":970,\"gold\":5578}}}}">>,
         <<"{\"s\":{\"db_data_verify\":{\"m\":{\"generate_index\":130}}}}">>,
         <<"{\"s\":{\"db_base\":{\"m\":{\"uid\":1049}},\"db_data_verify\":{\"m\":{\"generate_index\":129}},\"db_role\":{\"m\":{\"star\":5,\"cat_coin\":360,\"gold\":5554}}}}">>,
         <<"{\"s\":{\"db_logger\":{\"m\":{\"seed\":-1255669760,\"use_doublerocket\":0}},\"db_level\":{\"m\":{\"lv_end_gold\":true,\"flag_lv\":20}},\"db_data_verify\":{\"m\":{\"generate_index\":128}},\"db_activity\":{\"s\":{2001:{\"m\":{\"_left_sec\":206586}},5901:{\"m\":{\"_left_sec\":284462586}}}},\"db_role\":{\"m\":{\"level\":21,\"lv_tag\":21,\"lv_idx\":21}}}}">>,
         <<"{\"s\":{\"db_cat_feed\":{\"m\":{\"remain_food\":478.66666666667,\"food_time\":1608964610}},\"db_data_verify\":{\"m\":{\"generate_index\":127}},\"db_activity\":{\"s\":{2001:{\"m\":{\"_end_ti\":1609171200,\"_left_sec\":206590}},5901:{\"m\":{\"_left_sec\":284462590}}}},\"db_role\":{\"m\":{\"logout_time\":1608964610,\"play_time_sec\":960}}}}">>,
         <<"{\"s\":{\"db_data_verify\":{\"m\":{\"generate_index\":126}},\"db_activity\":{\"m\":{5901:{\"show_introduction\":true,\"_left_sec\":284462593,\"sign_day\":1,\"_end_ti\":1893427200,\"_start_ti\":1608964607,\"sign_times\":[],\"can_sign\":true,\"fb_start\":true},2001:{\"fb_start\":true,\"_left_sec\":206607,\"_start_ti\":1608964607,\"level_point_got\":0,\"_end_ti\":1609171214}}},\"db_role\":{\"m\":{\"logout_time\":1608964600,\"play_time_sec\":950}}}}">>,
         <<"{\"s\":{\"db_data_verify\":{\"m\":{\"generate_index\":125}}}}">>,
         <<"{\"s\":{\"db_base\":{\"m\":{\"uid\":1048}},\"db_level\":{\"m\":{\"lv_end_gold\":false}},\"db_data_verify\":{\"m\":{\"generate_index\":124}},\"db_role\":{\"m\":{\"gold\":5504}}}}">>,
         <<"{\"s\":{\"db_data_verify\":{\"m\":{\"generate_index\":123}}}}">>,
         <<"{\"s\":{\"db_base\":{\"m\":{\"uid\":1047}},\"db_data_verify\":{\"m\":{\"generate_index\":122}},\"db_role\":{\"m\":{\"star\":4,\"cat_coin\":340,\"gold\":5474}}}}">>,
         <<"{\"s\":{\"db_level\":{\"m\":{\"lv_end_gold\":true,\"flag_lv\":19}},\"db_logger\":{\"m\":{\"seed\":-711458816,\"use_doublerocket\":1}},\"db_tutorial\":{\"m\":{6:true}},\"db_data_verify\":{\"m\":{\"generate_index\":121}},\"db_role\":{\"m\":{\"logout_time\":1608964590,\"level\":20,\"lv_tag\":20,\"lv_idx\":20,\"play_time_sec\":940}}}}">>,
         <<"{\"s\":{\"db_data_verify\":{\"m\":{\"generate_index\":120}},\"db_role\":{\"m\":{\"logout_time\":1608964580,\"play_time_sec\":930}},\"db_tutorial\":{\"m\":{111:true}}}}">>,
         <<"{\"s\":{\"db_base\":{\"m\":{\"uid\":1046}},\"db_level\":{\"m\":{\"lv_end_gold\":false}},\"db_data_verify\":{\"m\":{\"generate_index\":119}},\"db_role\":{\"m\":{\"gold\":5424}}}}">>,
         <<"{\"s\":{\"db_data_verify\":{\"m\":{\"generate_index\":118}}}}">>,
         <<"{\"s\":{\"db_base\":{\"m\":{\"uid\":1045}},\"db_data_verify\":{\"m\":{\"generate_index\":117}},\"db_role\":{\"m\":{\"star\":3,\"cat_coin\":320,\"gold\":5399}}}}">>,
         <<"{\"s\":{\"db_logger\":{\"m\":{\"use_blackhole\":0,\"seed\":-1422000128}},\"db_level\":{\"m\":{\"lv_end_gold\":true,\"flag_lv\":18}},\"db_data_verify\":{\"m\":{\"generate_index\":116}},\"db_role\":{\"m\":{\"logout_time\":1608964570,\"level\":19,\"lv_tag\":19,\"lv_idx\":19,\"play_time_sec\":920}}}}">>,
         <<"{\"s\":{\"db_data_verify\":{\"m\":{\"generate_index\":115}},\"db_role\":{\"m\":{\"logout_time\":1608964560,\"play_time_sec\":910}}}}">>,
         <<"{\"s\":{\"db_base\":{\"m\":{\"uid\":1044}},\"db_level\":{\"m\":{\"lv_end_gold\":false}},\"db_data_verify\":{\"m\":{\"generate_index\":114}},\"db_role\":{\"m\":{\"gold\":5349}}}}">>,
         <<"{\"s\":{\"db_data_verify\":{\"m\":{\"generate_index\":113}}}}">>,
         <<"{\"s\":{\"db_base\":{\"m\":{\"uid\":1043}},\"db_data_verify\":{\"m\":{\"generate_index\":112}},\"db_role\":{\"m\":{\"star\":2,\"cat_coin\":300,\"gold\":5326}}}}">>,
         <<"{\"s\":{\"db_cat_feed\":{\"m\":{\"remain_food\":479.66666666667,\"food_time\":1608964550}},\"db_logger\":{\"m\":{\"use_blackhole\":1,\"seed\":-1776549888}},\"db_level\":{\"m\":{\"lv_end_gold\":true,\"flag_lv\":17}},\"db_data_verify\":{\"m\":{\"saved_index\":110,\"generate_index\":111,\"upload_data_time\":1608964550}},\"db_role\":{\"m\":{\"logout_time\":1608964550,\"level\":18,\"lv_tag\":18,\"lv_idx\":18,\"play_time_sec\":900}}}}">>,
         <<"{\"s\":{\"db_data_verify\":{\"m\":{\"generate_index\":110}},\"db_role\":{\"m\":{\"logout_time\":1608964540,\"play_time_sec\":890}},\"db_tutorial\":{\"m\":{110:true}}}}">>,
         <<"{\"s\":{\"db_cat_feed\":{\"m\":{\"first_add_money_time\":1608964534}},\"db_base\":{\"m\":{\"uid\":1042}},\"db_data_verify\":{\"m\":{\"generate_index\":109}},\"db_role\":{\"m\":{\"gold\":5276}}}}">>,
         <<"{\"s\":{\"db_base\":{\"s\":{\"talking_data\":{\"m\":{1069:[]}}}},\"db_chapter_map\":{\"s\":{2001:{\"s\":{\"stuffs\":{\"m\":{200104:{\"stuff_id\":200104,\"select_id\":1}}}}}}},\"db_cat_stuff_map\":{\"m\":{200104:{\"stuff_id\":200104,\"got_styles\":[1]}}},\"db_inland_server\":{\"m\":{\"story_progress\":24}},\"db_data_verify\":{\"m\":{\"generate_index\":108}},\"db_cat_feed\":{\"m\":{\"remain_food\":480,\"food_time\":1608964530,\"accum_food_time\":480}},\"db_role\":{\"m\":{\"logout_time\":1608964530,\"play_time_sec\":880}}}}">>,
         <<"{\"s\":{\"db_base\":{\"s\":{\"talking_data\":{\"m\":{1066:[]}}}},\"db_inland_server\":{\"m\":{\"story_progress\":23}},\"db_cat_stuff_map\":{\"m\":{200103:{\"stuff_id\":200103,\"got_styles\":[1]}}},\"db_tutorial\":{\"m\":{134:true}},\"db_data_verify\":{\"m\":{\"generate_index\":107}},\"db_chapter_map\":{\"s\":{2001:{\"s\":{\"stuffs\":{\"m\":{200103:{\"stuff_id\":200103,\"select_id\":1}}}}}}}}}">>,
         <<"{\"s\":{\"db_base\":{\"s\":{\"talking_data\":{\"m\":{1065:[]}}}},\"db_inland_server\":{\"m\":{\"story_progress\":22}},\"db_cat_stuff_map\":{\"m\":{200102:{\"stuff_id\":200102,\"got_styles\":[1]}}},\"db_tutorial\":{\"m\":{131:true}},\"db_data_verify\":{\"m\":{\"generate_index\":106}},\"db_chapter_map\":{\"s\":{2001:{\"s\":{\"stuffs\":{\"m\":{200102:{\"stuff_id\":200102,\"select_id\":1}}}}}}}}}">>,
         <<"{\"s\":{\"db_base\":{\"s\":{\"talking_data\":{\"m\":{1064:[]}}}},\"db_inland_server\":{\"m\":{\"story_progress\":21}},\"db_cat_stuff_map\":{\"m\":{200101:{\"stuff_id\":200101,\"got_styles\":[1]}}},\"db_tutorial\":{\"m\":{130:true,129:true}},\"db_data_verify\":{\"m\":{\"generate_index\":105}},\"db_chapter_map\":{\"s\":{2001:{\"s\":{\"stuffs\":{\"m\":{200101:{\"stuff_id\":200101,\"select_id\":1}}}},\"m\":{\"begin\":true}}}},\"db_role\":{\"m\":{\"logout_time\":1608964520,\"play_time_sec\":870}}}}">>,
         <<"{\"s\":{\"db_base\":{\"s\":{\"talking_data\":{\"m\":{20042:[]}}},\"m\":{\"uid\":1041}},\"db_chapter_map\":{\"s\":{2:{\"m\":{\"award_idx\":1}}},\"m\":{2001:{\"chapter\":2001,\"begin\":false,\"award_idx\":0,\"stuffs\":[]}}},\"db_talking_choose\":{\"m\":{\"20004-1\":true}},\"db_cat_map\":{\"m\":{4003:{\"name\":\"\">>,\"dress\":false,\"in_star_level\":0,\"dress_id\":0,\"level\":0,\"exp\":0,\"cat_id\":4003,\"have_list\":[]}}},\"db_inland_server\":{\"m\":{\"decorate_progress\":15,\"story_progress\":20}},\"db_data_verify\":{\"m\":{\"generate_index\":104}},\"db_role\":{\"m\":{\"logout_time\":1608964510,\"main_decorate_stuff\":204,\"play_time_sec\":860}},\"db_cat_room_map\":{\"m\":{2001:{\"toy_id_list\":[],\"chapter_id\":2001,\"cat_id_list\":[4001]}}}}}">>,
         <<"{\"s\":{\"db_base\":{\"s\":{\"talking_data\":{\"m\":{20032:[]}}}},\"db_chapter_map\":{\"s\":{2:{\"s\":{\"stuffs\":{\"m\":{204:{\"stuff_id\":204,\"select_id\":1}}}}}}},\"db_talking_choose\":{\"m\":{\"20002-1\":true,\"20003-1\":true}},\"db_data_verify\":{\"m\":{\"generate_index\":103}},\"db_inland_server\":{\"m\":{\"decorate_progress\":14,\"story_progress\":19}},\"db_role\":{\"m\":{\"main_decorate_stuff\":203,\"star\":1}}}}">>,
         <<"{\"s\":{\"db_data_verify\":{\"m\":{\"generate_index\":102}},\"db_chapter_map\":{\"s\":{2:{\"s\":{\"stuffs\":{\"m\":{203:{\"stuff_id\":203,\"select_id\":0}}}}}}},\"db_role\":{\"m\":{\"logout_time\":1608964500,\"star\":2,\"play_time_sec\":850}}}}">>,
         <<"{\"s\":{\"db_base\":{\"m\":{\"uid\":1040}},\"db_level\":{\"m\":{\"lv_end_gold\":false}},\"db_data_verify\":{\"m\":{\"generate_index\":101}},\"db_role\":{\"m\":{\"logout_time\":1608964490,\"play_time_sec\":840,\"gold\":5256}}}}">>,
         <<"{\"s\":{\"db_data_verify\":{\"m\":{\"generate_index\":100}}}}">>,
         <<"{\"s\":{\"db_base\":{\"m\":{\"uid\":1039}},\"db_data_verify\":{\"m\":{\"generate_index\":99}},\"db_role\":{\"m\":{\"star\":3,\"cat_coin\":280,\"gold\":5230}}}}">>,
         <<"{\"s\":{\"db_level\":{\"m\":{\"lv_end_gold\":true,\"flag_lv\":16}},\"db_logger\":{\"m\":{\"seed\":-1736310784,\"use_bombanddril\":0}},\"db_tutorial\":{\"m\":{10:true}},\"db_data_verify\":{\"m\":{\"generate_index\":98}},\"db_role\":{\"m\":{\"logout_time\":1608964482,\"level\":17,\"lv_tag\":17,\"lv_idx\":17,\"play_time_sec\":832}}}}">>,
         <<"{\"s\":{\"db_data_verify\":{\"m\":{\"generate_index\":97}},\"db_role\":{\"m\":{\"logout_time\":1608964470,\"play_time_sec\":820}}}}">>,
         <<"{\"s\":{\"db_base\":{\"m\":{\"uid\":1038}},\"db_level\":{\"m\":{\"lv_end_gold\":false}},\"db_data_verify\":{\"m\":{\"generate_index\":96}},\"db_role\":{\"m\":{\"gold\":5180}}}}">>,
         <<"{\"s\":{\"db_data_verify\":{\"m\":{\"generate_index\":95}}}}">>,
         <<"{\"s\":{\"db_base\":{\"m\":{\"uid\":1037}},\"db_data_verify\":{\"m\":{\"generate_index\":94}},\"db_role\":{\"m\":{\"star\":2,\"cat_coin\":260,\"gold\":5152}}}}">>,
         <<"{\"s\":{\"db_logger\":{\"m\":{\"seed\":1619525632,\"use_bombanddril\":1}},\"db_level\":{\"m\":{\"lv_end_gold\":true,\"flag_lv\":15}},\"db_data_verify\":{\"m\":{\"generate_index\":93}},\"db_role\":{\"m\":{\"logout_time\":1608964460,\"level\":16,\"lv_tag\":16,\"lv_idx\":16,\"play_time_sec\":810}}}}">>,
         <<"{\"s\":{\"db_data_verify\":{\"m\":{\"generate_index\":92}},\"db_role\":{\"m\":{\"logout_time\":1608964450,\"play_time_sec\":800}},\"db_tutorial\":{\"m\":{109:true}}}}">>,
         <<"{\"s\":{\"db_base\":{\"m\":{\"uid\":1036}},\"db_level\":{\"m\":{\"lv_end_gold\":false}},\"db_data_verify\":{\"m\":{\"generate_index\":91}},\"db_role\":{\"m\":{\"gold\":5102}}}}">>,
         <<"{\"s\":{\"db_data_verify\":{\"m\":{\"generate_index\":90}}}}">>,
         <<"{\"s\":{\"db_base\":{\"m\":{\"uid\":1035}},\"db_data_verify\":{\"m\":{\"generate_index\":89}},\"db_role\":{\"m\":{\"star\":1,\"cat_coin\":240,\"gold\":5076}}}}">>,
         <<"{\"s\":{\"db_logger\":{\"m\":{\"seed\":887881728}},\"db_level\":{\"m\":{\"lv_end_gold\":true,\"flag_lv\":14}},\"db_data_verify\":{\"m\":{\"generate_index\":88}},\"db_role\":{\"m\":{\"logout_time\":1608964440,\"level\":15,\"lv_tag\":15,\"lv_idx\":15,\"play_time_sec\":790}}}}">>,
         <<"{\"s\":{\"db_base\":{\"s\":{\"talking_data\":{\"m\":{20022:[]}}}},\"db_inland_server\":{\"m\":{\"decorate_progress\":13,\"story_progress\":18}},\"db_data_verify\":{\"m\":{\"generate_index\":87}},\"db_role\":{\"m\":{\"main_decorate_stuff\":202}}}}">>,
         <<"{\"s\":{\"db_data_verify\":{\"m\":{\"generate_index\":86}},\"db_chapter_map\":{\"s\":{2:{\"s\":{\"stuffs\":{\"m\":{202:{\"stuff_id\":202,\"select_id\":0}}}}}}},\"db_role\":{\"m\":{\"logout_time\":1608964430,\"star\":0,\"play_time_sec\":780}}}}">>,
         <<"{\"s\":{\"db_base\":{\"m\":{\"uid\":1034}},\"db_level\":{\"m\":{\"lv_end_gold\":false}},\"db_data_verify\":{\"m\":{\"generate_index\":85}},\"db_role\":{\"m\":{\"logout_time\":1608964420,\"play_time_sec\":770,\"gold\":5026}}}}">>,
         <<"{\"s\":{\"db_data_verify\":{\"m\":{\"generate_index\":84}}}}">>,
         <<"{\"s\":{\"db_base\":{\"m\":{\"uid\":1033}},\"db_data_verify\":{\"m\":{\"generate_index\":83}},\"db_role\":{\"m\":{\"star\":1,\"cat_coin\":220,\"gold\":5012}}}}">>,
         <<"{\"s\":{\"db_level\":{\"m\":{\"lv_end_gold\":true,\"flag_lv\":13}},\"db_logger\":{\"m\":{\"seed\":364380160}},\"db_tutorial\":{\"m\":{12:true}},\"db_data_verify\":{\"m\":{\"generate_index\":82}},\"db_role\":{\"m\":{\"logout_time\":1608964410,\"level\":14,\"lv_tag\":14,\"lv_idx\":14,\"play_time_sec\":760}}}}">>,
         <<"{\"s\":{\"db_base\":{\"s\":{\"talking_data\":{\"m\":{20012:[]}}}},\"db_inland_server\":{\"m\":{\"decorate_progress\":12,\"story_progress\":17}},\"db_talking_choose\":{\"m\":{\"20001-1\":true}},\"db_data_verify\":{\"m\":{\"generate_index\":81}},\"db_role\":{\"m\":{\"logout_time\":1608964390,\"main_decorate_stuff\":201,\"play_time_sec\":740}}}}">>,
         <<"{\"s\":{\"db_base\":{\"s\":{\"talking_data\":{\"d\":[10032,10081,10082,10052,10022,10112,10072,10042,10102,10012,10092,10062,10000],\"m\":{20001:[]}}}},\"db_chapter_map\":{\"s\":{2:{\"s\":{\"stuffs\":{\"m\":{201:{\"stuff_id\":201,\"select_id\":0}}}},\"m\":{\"begin\":true}}}},\"db_talking_choose\":{\"m\":{\"R1-12\":true}},\"db_data_verify\":{\"m\":{\"generate_index\":80}},\"db_inland_server\":{\"m\":{\"story_progress\":16}},\"db_role\":{\"m\":{\"logout_time\":1608964380,\"star\":0,\"play_time_sec\":730}}}}">>,
         <<"{\"s\":{\"db_base\":{\"s\":{\"talking_data\":{\"m\":{10112:[]}}},\"m\":{\"uid\":1032}},\"db_inland_server\":{\"m\":{\"decorate_progress\":11,\"story_progress\":14}},\"db_chapter_map\":{\"s\":[{\"m\":{\"award_idx\":2}}]},\"db_data_verify\":{\"m\":{\"generate_index\":79}},\"db_role\":{\"m\":{\"cat_coin\":200,\"main_decorate_stuff\":111,\"gold\":4962}}}}">>,
         <<"{\"s\":{\"db_base\":{\"s\":{\"talking_data\":{\"m\":{10102:[]}}}},\"db_chapter_map\":{\"s\":[{\"s\":{\"stuffs\":{\"m\":{111:{\"stuff_id\":111,\"select_id\":1}}}}}],\"m\":{2:{\"chapter\":2,\"begin\":false,\"award_idx\":0,\"stuffs\":[]}}},\"db_talking_choose\":{\"m\":{\"R1-11\":true}},\"db_data_verify\":{\"m\":{\"generate_index\":78}},\"db_inland_server\":{\"m\":{\"decorate_progress\":10,\"story_progress\":13}},\"db_role\":{\"m\":{\"chapter\":2,\"star\":1,\"logout_time\":1608964370,\"main_decorate_stuff\":110,\"play_time_sec\":720}}}}">>,
         <<"{\"s\":{\"db_base\":{\"s\":{\"talking_data\":{\"m\":{10092:[]}}}},\"db_chapter_map\":{\"s\":[{\"s\":{\"stuffs\":{\"m\":{110:{\"stuff_id\":110,\"select_id\":1}}}}}]},\"db_talking_choose\":{\"m\":{\"R1-9A\":true,\"R1-10A\":true}},\"db_data_verify\":{\"m\":{\"generate_index\":77}},\"db_inland_server\":{\"m\":{\"decorate_progress\":9,\"story_progress\":12}},\"db_role\":{\"m\":{\"logout_time\":1608964360,\"star\":2,\"main_decorate_stuff\":109,\"play_time_sec\":710}}}}">>,
         <<"{\"s\":{\"db_base\":{\"s\":{\"talking_data\":{\"m\":{10082:[]}}}},\"db_inland_server\":{\"m\":{\"decorate_progress\":8,\"story_progress\":11}},\"db_talking_choose\":{\"m\":{\"R1-8A\":true}},\"db_tutorial\":{\"m\":{108:true}},\"db_data_verify\":{\"m\":{\"generate_index\":76}},\"db_chapter_map\":{\"s\":[{\"s\":{\"stuffs\":{\"m\":{109:{\"stuff_id\":109,\"select_id\":1}}}}}]},\"db_role\":{\"m\":{\"logout_time\":1608964350,\"star\":3,\"main_decorate_stuff\":108,\"play_time_sec\":700}}}}">>,
         <<"{\"s\":{\"db_base\":{\"s\":{\"talking_data\":{\"m\":{10072:[],10081:[]}}}},\"db_chapter_map\":{\"s\":[{\"s\":{\"stuffs\":{\"m\":{108:{\"stuff_id\":108,\"select_id\":1}}}}}]},\"db_talking_choose\":{\"m\":{\"R1-7A\":true}},\"db_data_verify\":{\"m\":{\"generate_index\":75}},\"db_inland_server\":{\"m\":{\"decorate_progress\":7,\"story_progress\":10}},\"db_role\":{\"m\":{\"logout_time\":1608964340,\"star\":4,\"main_decorate_stuff\":107,\"play_time_sec\":690}}}}">>,
         <<"{\"s\":{\"db_base\":{\"s\":{\"talking_data\":{\"m\":{10062:[]}}}},\"db_inland_server\":{\"m\":{\"decorate_progress\":6,\"story_progress\":8}},\"db_chapter_map\":{\"s\":[{\"s\":{\"stuffs\":{\"m\":{107:{\"stuff_id\":107,\"select_id\":1}}}}}]},\"db_data_verify\":{\"m\":{\"generate_index\":74}},\"db_role\":{\"m\":{\"logout_time\":1608964330,\"star\":5,\"main_decorate_stuff\":106,\"play_time_sec\":680}}}}">>,
         <<"{\"s\":{\"db_data_verify\":{\"m\":{\"generate_index\":73}},\"db_chapter_map\":{\"s\":[{\"s\":{\"stuffs\":{\"m\":{106:{\"stuff_id\":106,\"select_id\":1}}}}}]},\"db_role\":{\"m\":{\"logout_time\":1608964320,\"star\":6,\"play_time_sec\":670}}}}">>,
         <<"{\"s\":{\"db_base\":{\"m\":{\"uid\":1031}},\"db_level\":{\"m\":{\"lv_end_gold\":false}},\"db_data_verify\":{\"m\":{\"generate_index\":72}},\"db_role\":{\"m\":{\"logout_time\":1608964310,\"play_time_sec\":660,\"gold\":1962}}}}">>,
         <<"{\"s\":{\"db_data_verify\":{\"m\":{\"generate_index\":71}}}}">>,
         <<"{\"s\":{\"db_base\":{\"m\":{\"uid\":1030}},\"db_data_verify\":{\"m\":{\"generate_index\":70}},\"db_role\":{\"m\":{\"star\":7,\"cat_coin\":100,\"gold\":1934}}}}">>,
         <<"{\"s\":{\"db_logger\":{\"m\":{\"seed\":-1906311168}},\"db_level\":{\"m\":{\"lv_end_gold\":true,\"flag_lv\":12}},\"db_data_verify\":{\"m\":{\"generate_index\":69}},\"db_role\":{\"m\":{\"logout_time\":1608964300,\"level\":13,\"lv_tag\":13,\"lv_idx\":13,\"play_time_sec\":650}}}}">>,
         <<"{\"s\":{\"db_data_verify\":{\"m\":{\"generate_index\":68}},\"db_role\":{\"m\":{\"logout_time\":1608964290,\"play_time_sec\":640}}}}">>,
         <<"{\"s\":{\"db_base\":{\"m\":{\"uid\":1029}},\"db_level\":{\"m\":{\"lv_end_gold\":false}},\"db_data_verify\":{\"m\":{\"generate_index\":67}},\"db_role\":{\"m\":{\"logout_time\":1608964280,\"play_time_sec\":630,\"gold\":1884}}}}">>,
         <<"{\"s\":{\"db_data_verify\":{\"m\":{\"generate_index\":66}}}}">>,
         <<"{\"s\":{\"db_base\":{\"m\":{\"uid\":1028}},\"db_data_verify\":{\"m\":{\"generate_index\":65}},\"db_role\":{\"m\":{\"star\":6,\"cat_coin\":80,\"gold\":1860}}}}">>,
         <<"{\"s\":{\"db_level\":{\"m\":{\"lv_end_gold\":true,\"flag_lv\":11}},\"db_logger\":{\"m\":{\"seed\":-1530396672}},\"db_tutorial\":{\"m\":{11:true}},\"db_data_verify\":{\"m\":{\"generate_index\":64}},\"db_role\":{\"m\":{\"logout_time\":1608964270,\"level\":12,\"lv_tag\":12,\"lv_idx\":12,\"play_time_sec\":620}}}}">>,
         <<"{\"s\":{\"db_data_verify\":{\"m\":{\"generate_index\":63}},\"db_role\":{\"m\":{\"logout_time\":1608964260,\"play_time_sec\":610}}}}">>,
         <<"{\"s\":{\"db_base\":{\"m\":{\"uid\":1027}},\"db_level\":{\"m\":{\"lv_end_gold\":false}},\"db_data_verify\":{\"m\":{\"saved_index\":61,\"generate_index\":62,\"upload_data_time\":1608964250}},\"db_role\":{\"m\":{\"logout_time\":1608964250,\"play_time_sec\":600,\"gold\":1810}}}}">>,
         <<"{\"s\":{\"db_data_verify\":{\"m\":{\"generate_index\":61}}}}">>,
         <<"{\"s\":{\"db_base\":{\"m\":{\"uid\":1026}},\"db_data_verify\":{\"m\":{\"generate_index\":60}},\"db_role\":{\"m\":{\"star\":5,\"cat_coin\":60,\"gold\":1782}}}}">>,
         <<"{\"s\":{\"db_level\":{\"m\":{\"lv_end_gold\":true,\"flag_lv\":10}},\"db_logger\":{\"m\":{\"seed\":1781137408}},\"db_tutorial\":{\"m\":{27:true}},\"db_data_verify\":{\"m\":{\"generate_index\":59}},\"db_role\":{\"m\":{\"logout_time\":1608964241,\"level\":11,\"lv_tag\":11,\"lv_idx\":11,\"play_time_sec\":591}}}}">>,
         <<"{\"s\":{\"db_data_verify\":{\"m\":{\"generate_index\":58}},\"db_role\":{\"m\":{\"logout_time\":1608964230,\"play_time_sec\":580}}}}">>,
         <<"{\"s\":{\"db_base\":{\"m\":{\"uid\":1025}},\"db_level\":{\"m\":{\"lv_end_gold\":false}},\"db_data_verify\":{\"m\":{\"generate_index\":57}},\"db_role\":{\"m\":{\"gold\":1732}}}}">>,
         <<"{\"s\":{\"db_data_verify\":{\"m\":{\"generate_index\":56}}}}">>,
         <<"{\"s\":{\"db_base\":{\"m\":{\"uid\":1024}},\"db_data_verify\":{\"m\":{\"generate_index\":55}},\"db_role\":{\"m\":{\"star\":4,\"cat_coin\":40,\"gold\":1704}}}}">>,
         <<"{\"s\":{\"db_logger\":{\"m\":{\"seed\":-166592512}},\"db_level\":{\"m\":{\"lv_end_gold\":true,\"flag_lv\":9}},\"db_data_verify\":{\"m\":{\"generate_index\":54}},\"db_role\":{\"m\":{\"logout_time\":1608964220,\"level\":10,\"lv_tag\":10,\"lv_idx\":10,\"play_time_sec\":570}}}}">>,
         <<"{\"s\":{\"db_data_verify\":{\"m\":{\"generate_index\":53}}}}">>,
         <<"{\"s\":{\"db_base\":{\"m\":{\"uid\":1023}},\"db_data_verify\":{\"m\":{\"generate_index\":52}},\"db_activity\":{\"m\":{1001:[]}},\"db_role\":{\"m\":{\"logout_time\":1608964210,\"play_time_sec\":560,\"gold\":1654}}}}">>,
         <<"{\"s\":{\"db_base\":{\"m\":{\"uid\":1022}},\"db_level\":{\"m\":{\"lv_end_gold\":false}},\"db_tutorial\":{\"m\":{57:true}},\"db_data_verify\":{\"m\":{\"generate_index\":51}},\"db_role\":{\"m\":{\"gold\":1554}}}}">>,
         <<"{\"s\":{\"db_data_verify\":{\"m\":{\"generate_index\":50}}}}">>,
         <<"{\"s\":{\"db_base\":{\"m\":{\"uid\":1021}},\"db_data_verify\":{\"m\":{\"generate_index\":49}},\"db_role\":{\"m\":{\"star\":3,\"cat_coin\":20,\"gold\":1526}}}}">>,
         <<"{\"s\":{\"db_logger\":{\"m\":{\"seed\":1123680256}},\"db_level\":{\"m\":{\"lv_end_gold\":true,\"flag_lv\":8}},\"db_data_verify\":{\"m\":{\"generate_index\":48}},\"db_role\":{\"m\":{\"logout_time\":1608964192,\"level\":9,\"lv_tag\":9,\"lv_idx\":9,\"play_time_sec\":542}}}}">>,
         <<"{\"s\":{\"db_data_verify\":{\"m\":{\"generate_index\":47}},\"db_role\":{\"m\":{\"logout_time\":1608964180,\"play_time_sec\":530}}}}">>,
         <<"{\"s\":{\"db_base\":{\"m\":{\"uid\":1020}},\"db_level\":{\"m\":{\"lv_end_gold\":false}},\"db_tutorial\":{\"m\":{7:true}},\"db_data_verify\":{\"m\":{\"generate_index\":46}},\"db_role\":{\"m\":{\"gold\":1476}}}}">>,
         <<"{\"s\":{\"db_data_verify\":{\"m\":{\"generate_index\":45}}}}">>,
         <<"{\"s\":{\"db_base\":{\"m\":{\"uid\":1019}},\"db_data_verify\":{\"m\":{\"generate_index\":44}},\"db_role\":{\"m\":{\"star\":2,\"gold\":1448}}}}">>,
         <<"{\"s\":{\"db_logger\":{\"m\":{\"seed\":-1272840192}},\"db_level\":{\"m\":{\"lv_end_gold\":true,\"flag_lv\":7}},\"db_data_verify\":{\"m\":{\"generate_index\":43}},\"db_role\":{\"m\":{\"level\":8,\"lv_tag\":8,\"lv_idx\":8}}}}">>,
         <<"{\"s\":{\"db_data_verify\":{\"m\":{\"generate_index\":42}},\"db_role\":{\"m\":{\"logout_time\":1608964170,\"play_time_sec\":520}}}}">>,
         <<"{\"s\":{\"db_base\":{\"m\":{\"uid\":1018}},\"db_level\":{\"m\":{\"lv_end_gold\":false}},\"db_data_verify\":{\"m\":{\"generate_index\":41}},\"db_role\":{\"m\":{\"logout_time\":1608964160,\"play_time_sec\":510,\"gold\":1398}}}}">>,
         <<"{\"s\":{\"db_data_verify\":{\"m\":{\"generate_index\":40}}}}">>,
         <<"{\"s\":{\"db_base\":{\"m\":{\"uid\":1017}},\"db_data_verify\":{\"m\":{\"generate_index\":39}},\"db_role\":{\"m\":{\"star\":1,\"gold\":1370}}}}">>,
         <<"{\"s\":{\"db_level\":{\"m\":{\"lv_end_gold\":true,\"flag_lv\":6}},\"db_logger\":{\"m\":{\"seed\":919470080}},\"db_tutorial\":{\"m\":{56:true}},\"db_data_verify\":{\"m\":{\"generate_index\":38}},\"db_role\":{\"m\":{\"level\":7,\"lv_tag\":7,\"lv_idx\":7}}}}">>,
         <<"{\"s\":{\"db_base\":{\"s\":{\"talking_data\":{\"m\":{10052:[]}}}},\"db_inland_server\":{\"m\":{\"decorate_progress\":5,\"story_progress\":7}},\"db_talking_choose\":{\"m\":{\"R1-6\":true}},\"db_data_verify\":{\"m\":{\"generate_index\":37}},\"db_role\":{\"m\":{\"logout_time\":1608964150,\"main_decorate_stuff\":105,\"play_time_sec\":500}}}}">>,
         <<"{\"s\":{\"db_data_verify\":{\"m\":{\"generate_index\":36}},\"db_chapter_map\":{\"s\":[{\"s\":{\"stuffs\":{\"m\":{105:{\"stuff_id\":105,\"select_id\":1}}}}}]},\"db_role\":{\"m\":{\"logout_time\":1608964140,\"star\":0,\"play_time_sec\":490}}}}">>,
         <<"{\"s\":{\"db_base\":{\"s\":{\"talking_data\":{\"m\":{10042:[]}}},\"m\":{\"uid\":1016}},\"db_chapter_map\":{\"s\":[{\"m\":{\"award_idx\":1}}]},\"db_talking_choose\":{\"m\":{\"R1-4\":true,\"R1-5A\":true}},\"db_data_verify\":{\"m\":{\"generate_index\":35}},\"db_cat_map\":{\"m\":{4002:{\"name\":\"\">>,\"dress\":false,\"in_star_level\":0,\"dress_id\":0,\"level\":0,\"exp\":0,\"cat_id\":4002,\"have_list\":[]}}},\"db_inland_server\":{\"m\":{\"decorate_progress\":4,\"story_progress\":6}},\"db_role\":{\"m\":{\"logout_time\":1608964130,\"main_decorate_stuff\":104,\"play_time_sec\":480}}}}">>,
         <<"{\"s\":{\"db_chapter_map\":{\"s\":[{\"s\":{\"stuffs\":{\"m\":{104:{\"stuff_id\":104,\"select_id\":1}}}}}]},\"db_tutorial\":{\"m\":{107:true}},\"db_data_verify\":{\"m\":{\"generate_index\":34}},\"db_role\":{\"m\":{\"logout_time\":1608964120,\"star\":1,\"play_time_sec\":470}}}}">>,
         <<"{\"s\":{\"db_base\":{\"m\":{\"uid\":1015}},\"db_level\":{\"m\":{\"lv_end_gold\":false}},\"db_data_verify\":{\"m\":{\"generate_index\":33}},\"db_role\":{\"m\":{\"logout_time\":1608964110,\"play_time_sec\":460,\"gold\":1320}}}}">>,
         <<"{\"s\":{\"db_data_verify\":{\"m\":{\"generate_index\":32}}}}">>,
         <<"{\"s\":{\"db_base\":{\"m\":{\"uid\":1014}},\"db_data_verify\":{\"m\":{\"generate_index\":31}},\"db_role\":{\"m\":{\"star\":2,\"gold\":1300}}}}">>,
         <<"{\"s\":{\"db_level\":{\"m\":{\"lv_end_gold\":true,\"flag_lv\":5}},\"db_logger\":{\"m\":{\"seed\":1919942656}},\"db_tutorial\":{\"m\":{5:true}},\"db_data_verify\":{\"m\":{\"generate_index\":30}},\"db_role\":{\"m\":{\"logout_time\":1608964100,\"level\":6,\"lv_tag\":6,\"lv_idx\":6,\"play_time_sec\":450}}}}">>,
         <<"{\"s\":{\"db_data_verify\":{\"m\":{\"generate_index\":29}},\"db_role\":{\"m\":{\"logout_time\":1608964070,\"play_time_sec\":420}}}}">>,
         <<"{\"s\":{\"db_base\":{\"m\":{\"uid\":1013}},\"db_level\":{\"m\":{\"lv_end_gold\":false}},\"db_data_verify\":{\"m\":{\"generate_index\":28}},\"db_role\":{\"m\":{\"logout_time\":1608964060,\"play_time_sec\":410,\"gold\":1250}}}}">>,
         <<"{\"s\":{\"db_data_verify\":{\"m\":{\"generate_index\":27}}}}">>,
         <<"{\"s\":{\"db_base\":{\"m\":{\"uid\":1012}},\"db_data_verify\":{\"m\":{\"generate_index\":26}},\"db_role\":{\"m\":{\"star\":1,\"gold\":1232}}}}">>,
         <<"{\"s\":{\"db_level\":{\"m\":{\"lv_end_gold\":true,\"flag_lv\":4}},\"db_logger\":{\"m\":{\"seed\":-889716736}},\"db_tutorial\":{\"m\":{4:true}},\"db_data_verify\":{\"m\":{\"generate_index\":25}},\"db_role\":{\"m\":{\"logout_time\":1608964050,\"level\":5,\"lv_tag\":5,\"lv_idx\":5,\"play_time_sec\":400}}}}">>,
         <<"{\"s\":{\"db_base\":{\"s\":{\"talking_data\":{\"m\":{10032:[]}}}},\"db_inland_server\":{\"m\":{\"decorate_progress\":3,\"story_progress\":5}},\"db_talking_choose\":{\"m\":{\"R1-3A\":true}},\"db_tutorial\":{\"m\":{106:true}},\"db_data_verify\":{\"m\":{\"generate_index\":24}},\"db_role\":{\"m\":{\"logout_time\":1608964000,\"main_decorate_stuff\":103,\"play_time_sec\":350}}}}">>,
         <<"{\"s\":{\"db_chapter_map\":{\"s\":[{\"s\":{\"stuffs\":{\"m\":{103:{\"stuff_id\":103,\"select_id\":0}}}}}]},\"db_tutorial\":{\"m\":{105:true}},\"db_data_verify\":{\"m\":{\"generate_index\":23}},\"db_role\":{\"m\":{\"logout_time\":1608963990,\"star\":0,\"play_time_sec\":340}}}}">>,
         <<"{\"s\":{\"db_base\":{\"m\":{\"uid\":1011}},\"db_level\":{\"m\":{\"lv_end_gold\":false}},\"db_data_verify\":{\"m\":{\"generate_index\":22}},\"db_role\":{\"m\":{\"logout_time\":1608963980,\"play_time_sec\":330,\"gold\":1182}}}}">>,
         <<"{\"s\":{\"db_data_verify\":{\"m\":{\"generate_index\":21}}}}">>,
         <<"{\"s\":{\"db_base\":{\"m\":{\"uid\":1010}},\"db_data_verify\":{\"m\":{\"generate_index\":20}},\"db_role\":{\"m\":{\"star\":1,\"gold\":1168}}}}">>,
         <<"{\"s\":{\"db_level\":{\"m\":{\"lv_end_gold\":true,\"flag_lv\":3}},\"db_logger\":{\"m\":{\"seed\":-411566080}},\"db_tutorial\":{\"m\":{3:true}},\"db_data_verify\":{\"m\":{\"saved_index\":18,\"generate_index\":19,\"upload_data_time\":1608963950}},\"db_role\":{\"m\":{\"logout_time\":1608963970,\"level\":4,\"lv_tag\":4,\"lv_idx\":4,\"play_time_sec\":320}}}}">>,
         <<"{\"s\":{\"db_base\":{\"s\":{\"talking_data\":{\"m\":{10022:[]}}}},\"db_inland_server\":{\"m\":{\"decorate_progress\":2,\"story_progress\":4}},\"db_talking_choose\":{\"m\":{\"R1-2A\":true}},\"db_tutorial\":{\"m\":{104:true}},\"db_data_verify\":{\"m\":{\"generate_index\":18}},\"db_role\":{\"m\":{\"logout_time\":1608963920,\"main_decorate_stuff\":102,\"play_time_sec\":270}}}}">>,
         <<"{\"s\":{\"db_chapter_map\":{\"s\":[{\"s\":{\"stuffs\":{\"m\":{102:{\"stuff_id\":102,\"select_id\":0}}}}}]},\"db_tutorial\":{\"m\":{103:true}},\"db_data_verify\":{\"m\":{\"generate_index\":17}},\"db_role\":{\"m\":{\"logout_time\":1608963910,\"star\":0,\"play_time_sec\":260}}}}">>,
         <<"{\"s\":{\"db_base\":{\"m\":{\"uid\":1009}},\"db_level\":{\"m\":{\"lv_end_gold\":false}},\"db_data_verify\":{\"m\":{\"generate_index\":16}},\"db_role\":{\"m\":{\"logout_time\":1608963870,\"play_time_sec\":220,\"gold\":1118}}}}">>,
         <<"{\"s\":{\"db_data_verify\":{\"m\":{\"generate_index\":15}}}}">>,
         <<"{\"s\":{\"db_base\":{\"m\":{\"uid\":1008}},\"db_data_verify\":{\"m\":{\"generate_index\":14}},\"db_role\":{\"m\":{\"star\":1,\"gold\":1100}}}}">>,
         <<"{\"s\":{\"db_level\":{\"m\":{\"flag_lv\":2}},\"db_logger\":{\"m\":{\"seed\":-392560640}},\"db_tutorial\":{\"m\":{2:true}},\"db_data_verify\":{\"m\":{\"generate_index\":13}},\"db_role\":{\"m\":{\"logout_time\":1608963860,\"level\":3,\"lv_tag\":3,\"lv_idx\":3,\"play_time_sec\":210}}}}">>,
         <<"{\"s\":{\"db_base\":{\"s\":{\"talking_data\":{\"m\":{10012:[]}}}},\"db_inland_server\":{\"m\":{\"decorate_progress\":1,\"story_progress\":3}},\"db_talking_choose\":{\"m\":{\"R1-1A\":true}},\"db_tutorial\":{\"m\":{102:true}},\"db_data_verify\":{\"m\":{\"generate_index\":12}},\"db_role\":{\"m\":{\"logout_time\":1608963780,\"main_decorate_stuff\":101,\"play_time_sec\":130}}}}">>,
         <<"{\"s\":{\"db_base\":{\"s\":{\"talking_data\":{\"m\":{1001:[]}}}},\"db_inland_server\":{\"m\":{\"story_progress\":2}},\"db_tutorial\":{\"m\":{101:true}},\"db_data_verify\":{\"m\":{\"generate_index\":11}},\"db_chapter_map\":{\"s\":[{\"s\":{\"stuffs\":{\"m\":{101:{\"stuff_id\":101,\"select_id\":0}}}}}]},\"db_role\":{\"m\":{\"logout_time\":1608963770,\"star\":0,\"play_time_sec\":120}}}}">>,
         <<"{\"s\":{\"db_data_verify\":{\"m\":{\"generate_index\":10}}}}">>,
         <<"{\"s\":{\"db_base\":{\"m\":{\"uid\":1007}},\"db_data_verify\":{\"m\":{\"generate_index\":9}},\"db_role\":{\"m\":{\"star\":1,\"gold\":1050}}}}">>,
         <<"{\"s\":{\"db_cat_gift_new\":{\"s\":{\"cur_gift\":{\"m\":{\"gift_id\":0,\"cat_id\":0,\"end_time\":0}}}},\"db_logger\":{\"m\":{\"seed\":775028736}},\"db_tutorial\":{\"m\":[true]},\"db_data_verify\":{\"m\":{\"generate_index\":8}},\"db_level\":{\"s\":{\"lv_failed_count\":{\"m\":{\"Empty\":[0,0,0]}}},\"m\":{\"eng_infinite_tag\":false,\"lv_end_gold\":true,\"flag_lv\":1}},\"db_role\":{\"m\":{\"logout_time\":1608963750,\"level\":2,\"lv_tag\":2,\"lv_idx\":2,\"play_time_sec\":100}}}}">>,
         <<"{\"s\":{\"db_base\":{\"s\":{\"talking_data\":{\"m\":{10000:[]}}}},\"db_inland_server\":{\"m\":{\"story_progress\":1}},\"db_data_verify\":{\"m\":{\"saved_index\":1,\"generate_index\":7,\"upload_data_time\":1608963651}},\"db_role\":{\"m\":{\"role_name\":\"Tyler\"}},\"db_monthcard\":{\"m\":{\"week_day\":6,\"left_os_time\":1608963651,\"day_left_time\":34749,\"day_left_os_time\":1608998400}}}}">>,
         <<"{\"s\":{\"db_cat_feed\":{\"m\":{\"shovel\":10}},\"db_data_verify\":{\"m\":{\"server_data_version_code\":1,\"generate_index\":6}},\"db_store_ad\":{\"m\":{\"today_cookie\":18622}}}}">>,
         <<"{\"s\":{\"db_data_verify\":{\"m\":{\"generate_index\":5}}}}">>,
         <<"{\"s\":{\"db_data_verify\":{\"m\":{\"generate_index\":4}},\"db_role\":{\"m\":{\"server_day_idx\":18622}},\"db_cat_gift_new\":{\"s\":{\"cur_gift\":{\"m\":{\"ad_watch\":0}}}}}}">>,
         <<"{\"s\":{\"db_chapter_map\":{\"s\":[{\"m\":{\"begin\":true}}]},\"db_level\":{\"m\":{\"activity_form\":\"Empty\"}},\"db_data_verify\":{\"m\":{\"generate_index\":3}},\"db_cat_ad\":{\"m\":{\"ad_num\":1,\"is_unlock\":true}}}}">>,
         <<"{\"s\":{\"db_data_verify\":{\"m\":{\"generate_index\":2}},\"db_logger\":{\"m\":{\"day_num\":1,\"day_idx\":18622}},\"db_cat_map\":{\"m\":{4001:{\"name\":\"\">>,\"dress\":false,\"in_star_level\":0,\"dress_id\":0,\"level\":0,\"exp\":0,\"cat_id\":4001,\"have_list\":[]}}},\"db_role\":{\"m\":{\"login_day_count\":1,\"last_login_day_index\":\"361\"}}}}">>
      ],
      client_map => #{}, cross_hammer => 4, d_rockets => 5, energy => 0,
      event_idx => 212, exchange => 4, game_time => 0, gold => 6416, hammer => 5,
      house_data =>
      "{\"db_stuff_timeline\":[],\"db_chapter_map\":[[\"chapter\",\"begin\",\"award_idx\",\"stuffs\"],[2001,2001,true,0,[3,3,3,3]]],\"db_stuff_child_visible\":[],\"version\":\"0.2.0\",\"db_item_list\":[],\"db_timeline_stuff_style\":[],\"db_cat_map\":[[\"name\",\"dress\",\"in_star_level\",\"cat_id\",\"level\",\"exp\",\"dress_id\",\"have_list\"],{1:4003,2:\"\",3:false,4:0,5:4003,6:0,7:0,8:0,9:[]},{1:4001,2:\"\",3:false,4:0,5:4001,6:0,7:0,8:0,9:[]}],\"db_cat_room_map\":[[\"toy_id_list\",\"chapter_id\",\"cat_id_list\"],[2001,[],2001,[4001,4003]]]}",
      key_data =>
      #{'$map_tab' => key_data,
         activity =>
         #{'$map_tab' => act_dv,
            act_comic_strips => #{5101 => {0, 2}},
            act_icecream_truck =>
            #{4001 =>
            {0,
               #{-1047817473 => 0, -884040730 => 0, 132422520 => 40},
               #{1 => 0}}},
            act_milk => #{2001 => {3, 1}},
            act_sign => 18622},
         ad =>
         #{21 => 0, 25 => 0, 53 => 0, 81 => 0, 83 => 0, 84 => 0, 86 => 0, 87 => 0,
            104 => 0, '$map_tab' => ad_dv, day => 18622},
         award_uid => 0,
         cat_room => {2001, [200104, 200103, 200102, 200101]},
         cats => <<"p">>,
         chapter => {202, 2, "ÔÓÒÑÐÏÎÍÌËÊÉ"},
         feed => {0, 0, 0, 0, 1},
         guide_awards => [[]],
         icons => <<>>,
         limit_room => {[], []},
         milk_bottle => 1, ml => [], special_back => #{}, spoint => 0,
         store => <<>>, styles => []
      },
      lv => 32, res_version => "0.2.0", role_id => 10010001, story => 1,
      sync_idx => 1, token => 0, upload_time => 1609147409, verify_result => 0,
      version => <<"0.0.0">>}.

get_test2() ->
   #{'$map_tab' => tb_client,
      black_hole => 4,
      bomb_drill => 4,
      cat_coin => 0,
      client_data => <<>>,
      %%<<123,34,100,98,95,97,119,97,114,100,95,109,97,112,34,58,91,93,44,34,100,98,95,99,97,116,95,103,105,102,116,34,58,123,34,109,97,120,95,97,119,97,114,100,95,110,117,109,34,58,102,97,108,115,101,44,34,97,119,97,114,100,95,110,117,109,34,58,102,97,108,115,101,44,34,115,116,97,114,116,95,116,105,34,58,48,44,34,108,101,102,116,95,115,101,99,34,58,48,44,34,97,119,97,114,100,115,34,58,102,97,108,115,101,44,34,101,110,100,95,116,105,34,58,48,44,34,102,105,114,115,116,95,102,101,101,100,95,103,105,102,116,34,58,102,97,108,115,101,44,34,115,101,108,101,99,116,95,104,111,117,114,95,116,121,112,101,34,58,102,97,108,115,101,125,44,34,100,98,95,99,97,116,95,97,100,34,58,123,34,105,115,95,117,110,108,111,99,107,34,58,116,114,117,101,44,34,97,100,95,110,117,109,34,58,49,44,34,99,100,95,116,105,109,101,34,58,48,125,44,34,100,98,95,99,108,111,116,104,101,115,95,111,117,116,95,99,97,116,34,58,91,93,44,34,100,98,95,99,97,116,95,101,118,101,110,116,34,58,123,34,110,117,109,34,58,48,44,34,105,115,95,117,110,108,111,99,107,34,58,102,97,108,115,101,44,34,105,115,95,105,110,105,116,34,58,102,97,108,115,101,44,34,115,116,97,114,116,95,116,105,109,101,34,58,48,125,44,34,100,98,95,102,105,110,105,115,104,101,100,95,97,99,116,105,118,105,116,121,34,58,91,93,44,34,100,98,95,105,110,108,97,110,100,95,115,101,114,118,101,114,34,58,123,34,117,117,105,100,34,58,34,34,44,34,100,101,99,111,114,97,116,101,95,112,114,111,103,114,101,115,115,34,58,51,44,34,97,99,99,111,117,110,116,95,99,104,97,110,110,101,108,34,58,34,34,44,34,99,104,97,110,110,101,108,95,114,111,108,101,34,58,91,93,44,34,98,105,110,100,95,97,99,99,111,117,110,116,95,97,119,97,114,100,34,58,102,97,108,115,101,44,34,115,116,111,114,121,95,112,114,111,103,114,101,115,115,34,58,53,44,34,108,97,115,116,95,97,99,99,111,117,110,116,95,99,104,97,110,110,101,108,34,58,34,34,125,44,34,100,98,95,99,104,97,112,116,101,114,95,109,97,112,34,58,91,91,34,115,116,117,102,102,115,34,44,34,97,119,97,114,100,95,105,100,120,34,44,34,98,101,103,105,110,34,44,34,99,104,97,112,116,101,114,34,93,44,91,49,44,91,49,44,49,44,49,93,44,48,44,116,114,117,101,44,49,93,93,44,34,100,98,95,116,105,109,101,108,105,110,101,95,115,116,117,102,102,95,115,116,121,108,101,34,58,91,93,44,34,100,98,95,99,97,116,95,103,105,102,116,95,110,101,119,34,58,123,34,103,105,102,116,115,34,58,91,93,44,34,105,115,95,117,110,108,111,99,107,34,58,102,97,108,115,101,44,34,99,117,114,95,103,105,102,116,34,58,123,34,97,100,95,119,97,116,99,104,34,58,48,44,34,103,105,102,116,95,105,100,34,58,48,44,34,99,97,116,95,105,100,34,58,48,44,34,101,110,100,95,116,105,109,101,34,58,48,125,125,44,34,100,98,95,112,114,111,99,101,115,115,34,58,123,34,112,114,111,99,101,115,115,34,58,91,93,125,44,34,100,98,95,105,110,108,97,110,100,95,105,100,105,112,34,58,123,34,99,111,105,110,95,98,101,102,111,114,101,95,99,111,117,110,116,34,58,48,44,34,99,111,105,110,95,111,112,116,95,105,100,34,58,48,44,34,99,111,105,110,95,97,102,116,101,114,95,99,111,117,110,116,34,58,48,44,34,98,97,110,100,95,106,111,105,110,95,114,97,110,107,105,110,103,95,105,110,102,111,34,58,91,93,44,34,99,111,105,110,95,102,114,101,101,122,101,95,105,110,102,111,34,58,48,125,44,34,100,98,95,108,101,118,101,108,34,58,123,34,102,108,97,103,95,108,118,34,58,53,44,34,108,118,95,101,110,100,95,103,111,108,100,34,58,102,97,108,115,101,44,34,108,101,118,101,108,95,98,117,121,95,116,105,109,101,34,58,48,44,34,101,110,103,95,105,110,102,105,110,105,116,101,95,116,97,103,34,58,102,97,108,115,101,44,34,97,99,116,105,118,105,116,121,95,102,111,114,109,34,58,34,69,109,112,116,121,34,44,34,108,118,95,102,97,105,108,110,95,97,100,118,105,99,101,34,58,48,44,34,108,101,118,101,108,95,105,116,101,109,95,108,105,115,116,34,58,91,93,44,34,117,115,101,95,105,116,101,109,95,108,105,115,116,34,58,91,93,44,34,99,111,110,116,105,110,117,101,95,99,111,115,116,34,58,48,44,34,108,118,95,116,121,112,101,34,58,48,44,34,115,101,116,95,114,101,115,117,108,116,34,58,48,44,34,108,101,118,101,108,95,115,116,97,116,101,34,58,48,44,34,108,118,95,102,97,105,108,101,100,95,99,111,117,110,116,34,58,123,34,69,109,112,116,121,34,58,91,48,44,48,44,48,93,125,125,44,34,100,98,95,116,117,116,111,114,105,97,108,34,58,123,48,58,51,49,44,51,58,49,48,48,56,125,44,34,100,98,95,99,97,116,95,115,116,117,102,102,95,109,97,112,34,58,91,93,44,34,100,98,95,100,97,116,97,95,118,101,114,105,102,121,34,58,123,34,115,101,114,118,101,114,95,100,97,116,97,95,118,101,114,115,105,111,110,95,99,111,100,101,34,58,49,44,34,115,97,118,101,100,95,105,110,100,101,120,34,58,49,44,34,117,112,108,111,97,100,95,100,97,116,97,95,116,105,109,101,34,58,49,54,48,57,57,57,48,52,56,55,44,34,103,101,110,101,114,97,116,101,95,105,110,100,101,120,34,58,51,56,125,44,34,100,98,95,97,99,116,105,118,105,116,121,95,115,101,116,116,108,101,34,58,123,34,105,110,102,105,110,105,116,101,95,99,104,97,108,108,101,110,103,101,95,105,110,102,111,34,58,91,48,44,48,44,48,93,125,44,34,100,98,95,98,97,115,101,34,58,123,34,116,97,108,107,105,110,103,95,100,97,116,97,34,58,123,49,48,48,51,50,58,91,93,44,49,48,48,49,58,91,93,44,49,48,48,49,50,58,91,93,44,49,48,48,50,50,58,91,93,44,49,48,48,48,48,58,91,93,125,44,34,117,105,100,34,58,49,48,49,53,44,34,116,97,108,107,105,110,103,95,115,99,101,110,101,95,105,110,102,111,34,58,91,93,125,44,34,100,98,95,109,111,110,116,104,99,97,114,100,34,58,123,34,99,97,114,100,95,100,97,121,34,58,48,44,34,99,97,114,100,95,105,100,34,58,48,44,34,116,97,103,34,58,48,44,34,100,97,121,95,108,101,102,116,95,116,105,109,101,34,58,52,52,55,49,51,44,34,100,97,121,95,108,101,102,116,95,111,115,95,116,105,109,101,34,58,49,54,49,48,48,51,53,50,48,48,44,34,108,101,102,116,95,111,115,95,116,105,109,101,34,58,49,54,48,57,57,57,48,52,56,55,44,34,108,101,102,116,95,115,101,99,34,58,48,44,34,115,104,111,119,95,109,111,110,116,104,99,97,114,100,95,99,101,108,108,34,58,91,93,44,34,104,97,118,101,95,103,111,116,34,58,102,97,108,115,101,44,34,119,101,101,107,95,100,97,121,34,58,52,44,34,100,105,115,99,95,110,117,109,34,58,48,125,44,34,100,98,95,116,97,108,107,105,110,103,95,99,104,111,111,115,101,34,58,123,34,82,49,45,49,65,34,58,116,114,117,101,44,34,82,49,45,51,65,34,58,116,114,117,101,44,34,82,49,45,50,65,34,58,116,114,117,101,125,44,34,100,98,95,99,97,116,95,115,116,111,114,121,34,58,91,93,44,34,100,98,95,99,97,116,95,102,101,101,100,34,58,123,34,114,101,109,97,105,110,95,102,111,111,100,34,58,48,44,34,109,111,110,101,121,95,116,105,109,101,34,58,48,44,34,114,101,109,97,105,110,95,119,97,116,101,114,34,58,48,44,34,102,111,111,100,95,116,105,109,101,34,58,48,44,34,102,105,114,115,116,95,97,100,100,95,109,111,110,101,121,95,116,105,109,101,34,58,48,44,34,97,99,99,117,109,95,102,111,111,100,95,116,105,109,101,34,58,48,44,34,99,108,101,97,110,95,102,114,100,95,116,105,109,101,34,58,91,93,44,34,109,111,110,101,121,95,108,105,115,116,34,58,91,93,44,34,97,99,99,117,109,95,119,97,116,101,114,95,116,105,109,101,34,58,48,44,34,97,99,99,117,109,95,109,111,110,101,121,34,58,48,44,34,117,115,101,100,95,115,104,111,118,101,108,34,58,48,44,34,119,97,116,101,114,95,116,105,109,101,34,58,48,44,34,108,97,115,116,95,97,100,100,95,100,97,121,34,58,48,44,34,114,101,109,97,105,110,95,109,111,110,101,121,34,58,48,44,34,100,97,121,95,105,110,100,101,120,34,58,48,44,34,115,104,111,118,101,108,34,58,49,48,125,44,34,100,98,95,97,99,116,105,118,105,116,121,34,58,91,93,44,34,100,98,95,99,97,116,95,101,120,116,114,97,34,58,123,34,117,110,108,111,99,107,95,108,105,115,116,34,58,91,93,125,44,34,100,98,95,104,101,97,100,34,58,123,34,115,104,111,119,95,104,101,97,100,34,58,34,49,34,44,34,111,119,110,95,104,101,97,100,34,58,91,93,125,44,34,100,98,95,99,97,116,95,114,111,111,109,95,109,97,112,34,58,91,93,44,34,100,98,95,115,116,117,102,102,95,116,105,109,101,108,105,110,101,34,58,91,93,44,34,100,98,95,99,97,116,95,114,101,108,97,116,105,111,110,34,58,123,52,48,48,50,58,91,51,93,44,52,48,48,49,58,91,49,93,125,44,34,100,98,95,108,111,103,103,101,114,34,58,123,34,100,97,121,95,105,100,120,34,58,49,56,54,51,52,44,34,103,111,108,100,95,99,111,115,116,34,58,48,44,34,100,97,121,95,110,117,109,34,58,49,44,34,111,110,108,105,110,101,95,115,101,99,34,58,53,57,53,48,44,34,117,115,101,95,100,111,117,98,108,101,114,111,99,107,101,116,34,58,48,44,34,115,101,101,100,34,58,49,57,49,57,57,52,50,54,53,54,44,34,99,111,105,110,95,99,111,115,116,34,58,48,44,34,108,111,103,34,58,48,44,34,117,115,101,95,104,97,109,109,101,114,34,58,48,44,34,117,115,101,95,103,108,111,118,101,34,58,48,44,34,114,101,115,104,117,102,102,108,101,34,58,48,44,34,117,115,101,95,99,114,111,115,115,104,97,109,109,101,114,34,58,48,44,34,117,115,101,95,98,108,97,99,107,104,111,108,101,34,58,48,44,34,117,115,101,95,98,111,109,98,97,110,100,100,114,105,108,34,58,48,44,34,112,97,121,95,110,117,109,34,58,48,125,44,34,100,98,95,109,97,105,108,95,108,105,115,116,34,58,91,93,44,34,100,98,95,99,97,116,95,109,97,112,34,58,91,91,34,108,101,118,101,108,34,44,34,104,97,118,101,95,108,105,115,116,34,44,34,99,97,116,95,105,100,34,44,34,101,120,112,34,44,34,100,114,101,115,115,34,44,34,105,110,95,115,116,97,114,95,108,101,118,101,108,34,44,34,110,97,109,101,34,44,34,100,114,101,115,115,95,105,100,34,93,44,123,49,58,52,48,48,49,44,50,58,48,44,51,58,91,93,44,52,58,52,48,48,49,44,53,58,48,44,54,58,102,97,108,115,101,44,55,58,48,44,56,58,34,34,44,57,58,48,125,93,44,34,100,98,95,115,116,111,114,101,95,97,100,34,58,123,34,116,111,100,97,121,95,99,111,111,107,105,101,34,58,49,56,54,51,52,44,34,119,97,116,99,104,101,100,95,99,111,117,110,116,34,58,48,44,34,110,101,120,116,95,97,100,95,116,105,109,101,34,58,48,125,44,34,100,98,95,114,111,108,101,34,58,123,34,108,101,118,101,108,34,58,54,44,34,114,111,108,101,95,110,97,109,101,34,58,34,230,183,177,232,164,144,231,154,132,231,133,142,232,155,139,34,44,34,115,112,101,99,105,97,108,95,112,111,105,110,116,34,58,48,44,34,112,108,97,121,95,116,105,109,101,95,115,101,99,34,58,53,57,53,48,44,34,101,110,101,114,103,121,95,116,105,109,101,34,58,48,44,34,108,111,103,105,110,95,116,105,109,101,34,58,49,54,48,57,57,57,53,54,53,54,44,34,98,104,95,105,110,102,105,110,105,116,101,95,108,101,102,116,95,115,101,99,34,58,48,44,34,108,111,103,111,117,116,95,116,105,109,101,34,58,49,54,48,57,57,57,53,54,53,54,44,34,104,97,118,101,95,115,105,103,110,34,58,91,93,44,34,108,118,95,116,97,103,34,58,54,44,34,98,100,95,105,110,102,105,110,105,116,101,95,108,101,102,116,95,115,101,99,34,58,48,44,34,99,104,97,112,116,101,114,34,58,49,44,34,109,97,120,95,112,114,111,100,117,99,116,95,105,100,34,58,48,44,34,101,110,101,114,121,103,95,105,110,102,105,110,105,116,101,95,108,101,102,116,95,116,105,109,101,115,34,58,48,44,34,115,112,101,110,100,95,109,111,110,101,121,34,58,48,44,34,116,117,116,111,114,105,97,108,95,111,110,34,58,116,114,117,101,44,34,116,111,107,101,110,34,58,48,44,34,102,105,114,115,116,95,116,108,118,34,58,116,114,117,101,44,34,102,98,95,102,105,114,115,116,95,97,119,97,114,100,34,58,102,97,108,115,101,44,34,115,101,114,118,101,114,95,100,97,121,95,105,100,120,34,58,49,56,54,51,52,44,34,115,101,114,118,101,114,95,109,97,105,108,95,105,100,34,58,48,44,34,115,116,97,114,34,58,50,44,34,100,114,95,105,110,102,105,110,105,116,101,34,58,48,44,34,101,110,101,114,103,121,34,58,53,44,34,98,104,95,105,110,102,105,110,105,116,101,34,58,48,44,34,100,105,97,109,111,110,100,34,58,48,44,34,101,110,101,114,103,121,95,105,110,102,105,110,105,116,101,34,58,48,44,34,103,111,108,100,34,58,49,51,48,55,44,34,108,111,103,105,110,95,100,97,121,95,99,111,117,110,116,34,58,49,44,34,103,111,108,100,95,114,101,34,58,48,44,34,98,100,95,105,110,102,105,110,105,116,101,34,58,48,44,34,108,118,95,105,100,120,34,58,54,44,34,100,114,95,105,110,102,105,110,105,116,101,95,108,101,102,116,95,115,101,99,34,58,48,44,34,99,97,116,95,99,111,105,110,34,58,48,44,34,115,101,108,102,95,114,111,111,109,95,115,116,97,114,115,34,58,48,44,34,97,100,95,114,101,109,97,105,110,105,110,103,95,110,117,109,34,58,48,44,34,110,101,119,112,108,97,121,101,114,95,115,105,103,110,105,110,95,99,111,109,112,108,101,116,101,34,58,48,44,34,108,97,115,116,95,108,111,103,105,110,95,100,97,121,95,105,110,100,101,120,34,58,34,48,48,55,34,44,34,111,114,100,101,114,95,105,100,95,108,105,115,116,34,58,91,93,44,34,101,110,101,114,103,121,95,114,101,99,111,118,101,114,95,104,97,108,118,101,34,58,48,44,34,109,97,105,110,95,100,101,99,111,114,97,116,101,95,115,116,117,102,102,34,58,49,48,51,125,44,34,100,98,95,105,116,101,109,95,108,105,115,116,34,58,91,91,34,105,116,101,109,95,117,105,100,34,44,34,105,116,101,109,95,110,117,109,34,44,34,105,116,101,109,95,116,105,100,34,93,44,91,49,44,49,48,48,49,44,52,44,49,48,48,54,93,44,91,50,44,49,48,48,50,44,52,44,49,48,48,55,93,44,91,51,44,49,48,48,51,44,52,44,49,48,48,56,93,44,91,52,44,49,48,48,52,44,52,44,49,48,49,53,93,44,91,53,44,49,48,48,53,44,52,44,49,48,49,54,93,44,91,54,44,49,48,48,54,44,52,44,49,48,49,55,93,93,44,34,100,98,95,115,116,117,102,102,95,99,104,105,108,100,95,118,105,115,105,98,108,101,34,58,91,93,44,34,100,98,95,99,97,116,95,99,104,97,114,97,99,116,101,114,34,58,123,52,48,48,49,58,91,49,44,50,93,125,125>>,
      client_idx => 1,
      client_incr => [],
      %%[<<"{\"s\":{\"db_data_verify\":{\"m\":{\"upload_data_time\":1609998581,\"generate_index\":43}},\"db_monthcard\":{\"m\":{\"left_os_time\":1609998581,\"day_left_time\":36619}},\"db_role\":{\"m\":{\"play_time_sec\":7360,\"logout_time\":1609999202}}}}">>,<<"{\"s\":{\"db_level\":{\"m\":{\"lv_end_gold\":true,\"set_result\":1,\"level_state\":2,\"flag_lv\":6}},\"db_tutorial\":{\"m\":{56:true}},\"db_logger\":{\"m\":{\"seed\":2103574528}},\"db_data_verify\":{\"m\":{\"generate_index\":42}},\"db_role\":{\"m\":{\"play_time_sec\":6730,\"logout_time\":1609998572}}}}">>,<<"{\"s\":{\"db_data_verify\":{\"m\":{\"upload_data_time\":1609997794,\"generate_index\":41}},\"db_monthcard\":{\"m\":{\"left_os_time\":1609997794,\"day_left_time\":37406}},\"db_role\":{\"m\":{\"play_time_sec\":6111,\"logout_time\":1609997953}}}}">>,<<"{\"s\":{\"db_data_verify\":{\"m\":{\"generate_index\":40}},\"db_role\":{\"m\":{\"login_time\":1609997792,\"logout_time\":1609997792}}}}">>],
      client_map => #{},
      cross_hammer => 4,
      d_rockets => 4,
      energy => 0, event_idx => 43, exchange => 4, game_time => 0, gold => 1307, hammer => 4,
      house_data => <<>>,
      key_data => #{
         '$map_tab' => key_data,
         activity => #{'$map_tab' => act_dv},
         ad => #{21 => 0, 25 => 0, 53 => 0, 81 => 0, 83 => 0, 84 => 0, 86 => 0, 87 => 0, 104 => 0, '$map_tab' => ad_dv, day => 18634},
         award_uid => 0, cat_room => {2001, []},
         cats => <<"@">>, chapter => {0, 1, "gfe"},
         character => #{4001 => [2, 1]},
         feed => {0, 0, 0, 0, 0},
         guide_awards => [10012111, 10000],
         icons => <<>>,
         limit_room => {[], []},
         milk_bottle => 0,
         ml => [],
         special_back => #{},
         spoint => 0,
         store => <<>>,
         story_list => [10012, 10000],
         styles => []
      },

      lv => 6,
      res_version => "0.9.5", role_id => 10010001, story => 2, sync_idx => 1,
      token => 0, upload_time => 1609999206, verify_result => 0
   }.

gc() ->
   lists:foreach(fun(Pid) -> erlang:garbage_collect(Pid) end, erlang:processes()),
   erlang:garbage_collect().

tt_w1(Term) ->
   ?MEM_INFO_INIT(),
   io_lib:format("~w", [Term]),
   ?MEM_INFO_PRINT(0).

tt_w2(Term) ->
   ?MEM_INFO_INIT(),
   eFmt:format("~w", [Term]),
   ?MEM_INFO_PRINT(0).

tt_w11() ->
   ?MEM_INFO_INIT(),
   io_lib:format("~w", [get_test()]),
   ?MEM_INFO_PRINT(0).

tt_w12() ->
   ?MEM_INFO_INIT(),
   eFmt:format("~w", [get_test()]),
   ?MEM_INFO_PRINT(0).

tt_w21() ->
   ?MEM_INFO_INIT(),
   io_lib:format("~w", [get_test2()]),
   ?MEM_INFO_PRINT(0).

tt_w22() ->
   ?MEM_INFO_INIT(),
   eFmt:format(<<"~w">>, [get_test2()]),
   ?MEM_INFO_PRINT(0).

tt_p1(Term) ->
   ?MEM_INFO_INIT(),
   io_lib:format("~p", [Term]),
   ?MEM_INFO_PRINT(0).

tt_p2(Term) ->
   ?MEM_INFO_INIT(),
   eFmt:format("~p", [Term]),
   ?MEM_INFO_PRINT(0).

tt_p11() ->
   ?MEM_INFO_INIT(),
   io_lib:format("~p", [get_test()]),
   ?MEM_INFO_PRINT(0).

tt_p12() ->
   ?MEM_INFO_INIT(),
   eFmt:format("~p", [get_test()]),
   ?MEM_INFO_PRINT(0).

tt_p21() ->
   ?MEM_INFO_INIT(),
   io_lib:format("~p", [get_test2()]),
   ?MEM_INFO_PRINT(0).

tt_p22() ->
   ?MEM_INFO_INIT(),
   eFmt:format(<<"~p">>, [get_test2()]),
   ?MEM_INFO_PRINT(0).

-define(SQL_ROLE_CHAT_DATA_UPDATE, <<"update `role_chat` set `channels`='~s', `sensitive`=~p, `ban_times`=~p, `time`=~p where `role_id`=~p">>).

tt_s1() ->
   ?MEM_INFO_INIT(),
   io_lib:format(?SQL_ROLE_CHAT_DATA_UPDATE, [<<"YYYY">>, [abcdef, 134, 423], {adfs, gfdgfg, "fdsfdsfs"}, #{aaaa => bbb, vvv => dddd}, self()]),
   ?MEM_INFO_PRINT(0).

tt_s2() ->
   ?MEM_INFO_INIT(),
   eFmt:format(?SQL_ROLE_CHAT_DATA_UPDATE, [<<"YYYY">>, [abcdef, 134, 423], {adfs, gfdgfg, "fdsfdsfs"}, #{aaaa => bbb, vvv => dddd}, self()]),
   ?MEM_INFO_PRINT(0).

for(0, _M, _F, _A) ->
   ok;
for(N, M, F, A) ->
   apply(M, F, A),
   for(N - 1, M, F, A).

tt_FP1(N) ->
   ?MEM_INFO_INIT(),
   for(N, io_lib, format, ["~p", [get_test2()]]),
   ?MEM_INFO_PRINT(0).

tt_FP2(N) ->
   ?MEM_INFO_INIT(),
   for(N, eFmt, format, [<<"~p">>, [get_test2()]]),
   ?MEM_INFO_PRINT(0).

tt_FW1(N) ->
   ?MEM_INFO_INIT(),
   for(N, io_lib, format, ["~w", [get_test2()]]),
   ?MEM_INFO_PRINT(0).

tt_FW2(N) ->
   ?MEM_INFO_INIT(),
   for(N, eFmt, format, [<<"~w">>, [get_test2()]]),
   ?MEM_INFO_PRINT(0).

tt_FS1(N) ->
   ?MEM_INFO_INIT(),
   for(N, io_lib, format, [?SQL_ROLE_CHAT_DATA_UPDATE, [<<"YYYY">>, [abcdef, 134, 423], {adfs, gfdgfg, "fdsfdsfs"}, #{aaaa => bbb, vvv => dddd}, self()]]),
   ?MEM_INFO_PRINT(0).

tt_FS2(N) ->
   ?MEM_INFO_INIT(),
   for(N, eFmt, format, [?SQL_ROLE_CHAT_DATA_UPDATE, [<<"YYYY">>, [abcdef, 134, 423], {adfs, gfdgfg, "fdsfdsfs"}, #{aaaa => bbb, vvv => dddd}, self()]]),
   ?MEM_INFO_PRINT(0).

tt_FM1(N) ->
   ?MEM_INFO_INIT(),
   for(N, eFmt, writeTerm, [get_test2(), -1, unicode]),
   ?MEM_INFO_PRINT(0).

tt_FM2(N) ->
   ?MEM_INFO_INIT(),
   for(N, eFmt, writeTerm, [get_test2(), -1, 120, unicode, true]),
   ?MEM_INFO_PRINT(0).


tt_m1() ->
   ?MEM_INFO_INIT(),
   eFmt:writeTerm(get_test2(), -1, unicode),
   ?MEM_INFO_PRINT(0).

tt_m2() ->
   ?MEM_INFO_INIT(),
   eFmt:writeTerm(get_test2(), -1, 120, unicode, true),
   ?MEM_INFO_PRINT(0).

tt_Fmap1(N) ->
   ?MEM_INFO_INIT(),
   for(N, ?MODULE, writeMap1, [get_test2(), -1, unicode, <<"#{">>]),
   ?MEM_INFO_PRINT(0).

tt_Fmap2(N) ->
   ?MEM_INFO_INIT(),
   for(N, ?MODULE, writeMap2, [get_test2(), -1, unicode, <<"#{">>]),
   ?MEM_INFO_PRINT(0).


writeMap1(Map, D, E, BinAcc) ->
   if
      D =:= 1 ->
         <<BinAcc/binary, "...}">>;
      true ->
         writeMapBody1(maps:iterator(Map), D, E, BinAcc)
   end.

writeMapBody1(I, D, E, BinAcc) ->
   if
      D =:= 1 ->
         <<BinAcc/binary, " ...}">>;
      true ->
         case maps:next(I) of
            {K, V, none} ->
               <<BinAcc/binary, (eFmt:writeTerm(K, -1, E))/binary, " => ", (eFmt:writeTerm(V, D, E))/binary, "}">>;
            {K, V, NextI} ->
               writeMapBody1(NextI, D - 1, E, <<BinAcc/binary, (eFmt:writeTerm(K, -1, E))/binary, " => ", (eFmt:writeTerm(V, D, E))/binary, ",">>);
            _ ->
               <<BinAcc/binary, "}">>
         end
   end.

writeMap2(Map, D, E, BinAcc) ->
   if
      D =:= 1 ->
         <<BinAcc/binary, "...}">>;
      true ->
         writeMapBody2(maps:iterator(Map), D, E, BinAcc)
   end.

writeMapBody2(I, D, E, BinAcc) ->
   if
      D =:= 1 ->
         <<BinAcc/binary, " ...}">>;
      true ->
         case maps:next(I) of
            {K, V, none} ->
               KeyTermBin = eFmt:writeTerm(K, -1, E),
               ValueTermBin = eFmt:writeTerm(V, -1, E),
               <<BinAcc/binary, KeyTermBin/binary, " => ", ValueTermBin/binary, "}">>;
            {K, V, NextI} ->
               KeyTermBin = eFmt:writeTerm(K, -1, E),
               ValueTermBin = eFmt:writeTerm(V, -1, E),
               writeMapBody2(NextI, D - 1, E, <<BinAcc/binary, KeyTermBin/binary, " => ", ValueTermBin/binary, ",">>);
            _ ->
               <<BinAcc/binary, "}">>
         end
   end.

tss1(K, V, E, BinAcc) ->
   tss1(K, V, E,  <<BinAcc/binary, (eFmt:writeTerm(K, -1, E))/binary, " => ", (eFmt:writeTerm(V, -1, E))/binary, ",">>).


tss2(K, V, E, BinAcc) ->
   KeyTermBin = eFmt:writeTerm(K, -1, E),
   ValueTermBin = eFmt:writeTerm(V, -1, E),
   tss1(K, V, E,   <<BinAcc/binary, KeyTermBin/binary, " => ", ValueTermBin/binary, ",">>).
